<?php

header('Content-Type: application/json');

$retour = array();

try {
    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Pagination
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1; // Numéro de la page, par défaut à la première page
    $limit = 10; // Nombre de résultats par page
    $offset = ($page - 1) * $limit; // Décalage (offset) pour la pagination

    // Requête pour récupérer la liste des accidents avec pagination
    $requestAccidents = $connexion->prepare("SELECT Accidents.*, V.*, Marque.nom AS nom_marque, Modele.nom AS nom_modele, TypeVehicule.nomType AS nom_type, Clients.nom AS nom_client, Clients.prenom AS prenom_client
        FROM Accidents
        INNER JOIN Vehicule AS V ON Accidents.idVehicule = V.idVehicule
        JOIN Marque ON V.idMarque = Marque.idMarque
        JOIN TypeVehicule ON V.idTypeVehicule = TypeVehicule.idTypeVehicule
        JOIN Modele ON V.idModele = Modele.idModele
        JOIN Clients ON Accidents.idClient = Clients.idClient
        LIMIT :limit OFFSET :offset");
    $requestAccidents->bindParam(':limit', $limit, PDO::PARAM_INT);
    $requestAccidents->bindParam(':offset', $offset, PDO::PARAM_INT);
    $requestAccidents->execute();
    $accidents = $requestAccidents->fetchAll(PDO::FETCH_ASSOC);

    // Requête pour compter le nombre total d'accidents
    $countTotalAccident = $connexion->query("SELECT COUNT(*) AS total FROM Accidents");
    $totalAccident = $countTotalAccident->fetchColumn();

    // Calcul du nombre total de pages
    $totalPages = ceil($totalAccident / $limit);

    $hasMore = count($accidents) == $limit; // Vérifie s'il y a plus d'accidents à charger

    $retour["success"] = true;
    $retour["accidents"] = $accidents;
    $retour["totalPages"] = $totalPages;
    $retour["hasMore"] = $hasMore;

} catch (PDOException $ex) {
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données: " . $ex->getMessage();
}

// Envoi de la réponse JSON
echo json_encode($retour);

?>
