<?php

header('Content-Type: application/json');

$retour = array();

try {
    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Pagination
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1; // Numéro de la page, par défaut à la première page
    $limit = 10; // Nombre de résultats par page
    $offset = ($page - 1) * $limit; // Décalage (offset) pour la pagination

    // Requête pour récupérer la liste des assurances avec pagination
    $requestAssurances = $connexion->prepare("SELECT Assurance.*, V.*, Marque.nom AS nom_marque, Modele.nom AS nom_modele, TypeVehicule.nomType AS nom_type
        FROM Assurance
        INNER JOIN Vehicule AS V ON Assurance.idVehicule = V.idVehicule
        JOIN Marque ON V.idMarque = Marque.idMarque
        JOIN TypeVehicule ON V.idTypeVehicule = TypeVehicule.idTypeVehicule
        JOIN Modele ON V.idModele = Modele.idModele
        LIMIT :limit OFFSET :offset");
    $requestAssurances->bindParam(':limit', $limit, PDO::PARAM_INT);
    $requestAssurances->bindParam(':offset', $offset, PDO::PARAM_INT);
    $requestAssurances->execute();
    $assurances = $requestAssurances->fetchAll(PDO::FETCH_ASSOC);

    // Requête pour récupérer le nombre total d'assurances
    $requeteTotalAssurance = $connexion->query("SELECT COUNT(*) AS total FROM Assurance");
    $totalAssurance = $requeteTotalAssurance->fetchColumn();

    // Calcul du nombre total de pages
    $totalPages = ceil($totalAssurance / $limit);

    $hasMore = count($assurances) == $limit; // Vérifie s'il y a plus d'assurances à charger

    $retour["success"] = true;
    $retour["assurances"] = $assurances;
    $retour["totalPages"] = $totalPages;
    $retour["hasMore"] = $hasMore;

} catch (PDOException $ex) {
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données: " . $ex->getMessage();
}

// Envoi de la réponse JSON
echo json_encode($retour);

?>
