<?php

header('Content-Type: application/json');

$retour = array();

try {
    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Paramètres de pagination
    $limit = 10; // Nombre d'éléments par page
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1; 

    // Calcul de l'offset
    $offset = ($page - 1) * $limit;

    // Requête pour récupérer la liste paginée des contrats avec les informations sur les véhicules et les clients
    $query = "SELECT 
                Vehicule.*,
                ContratsLocation.*,
                Marque.nom AS nom_marque, 
                Modele.nom AS nom_modele, 
                TypeVehicule.nomType AS nom_type, 
                Statut.Statut AS statut, 
                idContrat AS contrat_id, 
                Clients.nom AS nom_client
              FROM 
                Vehicule
              JOIN 
                Marque ON Vehicule.idMarque = Marque.idMarque
              JOIN 
                TypeVehicule ON Vehicule.idTypeVehicule = TypeVehicule.idTypeVehicule
              JOIN 
                Modele ON Vehicule.idModele = Modele.idModele
              JOIN 
                Statut ON Vehicule.idStatut = Statut.idStatut
              JOIN 
                ContratsLocation ON Vehicule.idVehicule = ContratsLocation.idVehicule
              JOIN 
                Clients ON ContratsLocation.idClient = Clients.idClient
              LIMIT :limit OFFSET :offset";

    $requestContrats = $connexion->prepare($query);
    $requestContrats->bindValue(':limit', $limit, PDO::PARAM_INT);
    $requestContrats->bindValue(':offset', $offset, PDO::PARAM_INT);
    $requestContrats->execute();
    
    // Récupération des contrats
    $contrats = $requestContrats->fetchAll(PDO::FETCH_ASSOC);

    // Requête pour récupérer le nombre total de contrats
    $countTotalContrats = $connexion->query("SELECT COUNT(*) AS total FROM ContratsLocation");
    $totalContrats = $countTotalContrats->fetchColumn();

    // Calcul du nombre total de pages
    $totalPages = ceil($totalContrats / $limit);

    // Déterminer s'il y a plus de contrats à charger
   $hasMore = ($offset + $limit) < $totalContrats;


    // Ajout des informations sur les pages et l'indicateur hasMore à la réponse
    $retour["success"] = true;
    $retour["contrats"] = $contrats;
    $retour["totalPages"] = $totalPages;
    $retour["hasMore"] = $hasMore;
} catch (PDOException $ex) {
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données: " . $ex->getMessage();
}

// Envoi de la réponse JSON
echo json_encode($retour);
?>
