<?php

header('Content-Type: application/json');

$retour = array();

try {
    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Paramètres de pagination
    $limit = 10; // Nombre d'éléments par page
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1; // Page demandée, par défaut la première

    // Calcul de l'offset
    $offset = ($page - 1) * $limit;

    // Requête pour récupérer la liste paginée des Factures
    $requestFacturation = $connexion->prepare("
SELECT 
    f.idFacture,
    f.idClient,
    c.nom AS nom_client,
    c.prenom AS prenom_client,
    f.Montant,
    f.DateFacturation,
    f.Statut
FROM 
    Facturation f
JOIN 
    Clients c ON f.idClient = c.idClient
LIMIT :limit OFFSET :offset");
    $requestFacturation->bindValue(':limit', $limit, PDO::PARAM_INT);
    $requestFacturation->bindValue(':offset', $offset, PDO::PARAM_INT);
    $requestFacturation->execute();
    
    // Récupération des factures
    $facturation = $requestFacturation->fetchAll(PDO::FETCH_ASSOC);

    // Requête pour récupérer le nombre total de factures
    $countTotalFactures = $connexion->query("SELECT COUNT(*) AS total FROM Facturation");
    $totalFactures = $countTotalFactures->fetchColumn();

    // Calcul du nombre total de pages
    $totalPages = ceil($totalFactures / $limit);

    // Déterminer s'il y a plus de factures à charger
    $hasMore = ($offset + $limit) < $totalFactures;

    // Ajout des informations sur les pages et l'indicateur hasMore à la réponse
    $retour["success"] = true;
    $retour["factures"] = $facturation;
    $retour["totalPages"] = $totalPages;
    $retour["hasMore"] = $hasMore;
} catch (PDOException $ex) {
    // En cas d'erreur PDO, enregistrer l'erreur dans les logs
    error_log("Erreur PDO: " . $ex->getMessage());
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données.";
} catch (Exception $ex) {
    // En cas d'autre exception, enregistrer l'erreur dans les logs
    error_log("Erreur: " . $ex->getMessage());
    $retour["success"] = false;
    $retour["error"] = "Une erreur est survenue lors de la récupération des factures.";
}

// Envoi de la réponse JSON
echo json_encode($retour);
?>
