<?php

header('Content-Type: application/json');

$retour = array();

try {
    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Pagination
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1; // Numéro de la page, par défaut à la première page
    $limit = 10; // Nombre de résultats par page
    $offset = ($page - 1) * $limit; // Décalage (offset) pour la pagination

    // Requête pour récupérer les documents des clients avec pagination
    $requeteDocsClients = $connexion->prepare("SELECT Clients.*, Genre.*, DocumentsClient.*
        FROM Clients
        INNER JOIN Genre ON Clients.idGenre = Genre.idGenre
        INNER JOIN DocumentsClient ON DocumentsClient.idClient = Clients.idClient
        LIMIT :limit OFFSET :offset");
    $requeteDocsClients->bindValue(':limit', $limit, PDO::PARAM_INT);
    $requeteDocsClients->bindValue(':offset', $offset, PDO::PARAM_INT);
    $requeteDocsClients->execute();

    // Récupération des résultats de la requête
    $docsClients = $requeteDocsClients->fetchAll(PDO::FETCH_ASSOC);

    // Requête pour récupérer le nombre total de documents des clients
    $requeteTotalDocsClients = $connexion->query("SELECT COUNT(*) AS total FROM DocumentsClient");
    $totalDocsClients = $requeteTotalDocsClients->fetchColumn();

    // Calcul du nombre total de pages
    $totalPages = ceil($totalDocsClients / $limit);

    // Ajout des documents des clients et du nombre total de pages à la réponse
    $retour["success"] = true;
    $retour["docsClients"] = $docsClients;
    $retour["totalPages"] = $totalPages;
    $retour["hasMore"] = count($docsClients) == $limit; // Indique s'il y a plus de documents à charger
} catch (PDOException $ex) {
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données: " . $ex->getMessage();
}

// Envoi de la réponse JSON
echo json_encode($retour);
?>
