<?php

header('Content-Type: application/json');

$retour = array();

try {
    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Détermine la page à afficher et le nombre d'éléments par page
    $page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
    $elementsParPage = 10; // Changez cela en fonction du nombre d'états que vous voulez afficher par page

    // Calculer l'offset pour la requête SQL
    $offset = ($page - 1) * $elementsParPage;

    // Requête pour récupérer la liste des états avec pagination
    $requestEtats = $connexion->prepare("
        SELECT Etat.*, Genre.genre AS Genre_Client, Clients.nom AS Nom_Client, Marque.nom AS Nom_Marque, Modele.nom AS Nom_Modele, Vehicule.Immat AS Immatriculation_Vehicule
        FROM Etat
        JOIN Clients ON Etat.idClient = Clients.idClient
        JOIN Vehicule ON Etat.idVehicule = Vehicule.idVehicule
        JOIN Genre ON Genre.idGenre = Clients.idGenre
        JOIN Marque ON Marque.idMarque = Vehicule.idMarque
        JOIN Modele ON Modele.idModele = Vehicule.idModele
        LIMIT :offset, :elementsParPage
    ");
    $requestEtats->bindParam(':offset', $offset, PDO::PARAM_INT);
    $requestEtats->bindParam(':elementsParPage', $elementsParPage, PDO::PARAM_INT);
    $requestEtats->execute();
    $etats = $requestEtats->fetchAll(PDO::FETCH_ASSOC);

    // Requête pour compter le nombre total d'éléments (états)
    $countTotalEtats = $connexion->query("SELECT COUNT(*) AS total FROM Etat");
    $totalEtats = $countTotalEtats->fetchColumn();

    // Calcul du nombre total de pages
    $totalPages = ceil($totalEtats / $elementsParPage);

    // Vérifie s'il y a des états
    $hasMore = count($etats) == $elementsParPage; // Vérifie s'il y a plus d'états à charger

    $retour["success"] = true;
    $retour["etats"] = $etats;
    $retour["totalPages"] = $totalPages; // Ajoute le nombre total de pages à la réponse JSON
    $retour["hasMore"] = $hasMore; // Ajoute l'indicateur hasMore à la réponse JSON

} catch (PDOException $ex) {
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données: " . $ex->getMessage();
}

// Envoi de la réponse JSON
echo json_encode($retour);
?>
