<?php

header('Content-Type: application/json');

$retour = array();

try {
    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $ex) {
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données: " . $ex->getMessage();
    echo json_encode($retour);
    exit;
}

$email = isset($_POST['email']) ? $_POST['email'] : null;
$nom = isset($_POST['name']) ? $_POST['name'] : null;
$password = isset($_POST['password']) ? $_POST['password'] : null;

if (!$email || !$nom || !$password) {
    $retour["success"] = false;
    $retour["error"] = "Veuillez fournir l'email, le nom et le mot de passe.";
    echo json_encode($retour);
    exit;
}

// Hacher le mot de passe
$hashedPassword = password_hash($password, PASSWORD_DEFAULT);

// Préparation de la requête d'insertion
$requestInsert = $connexion->prepare("INSERT INTO Utilisateurs (email, nom, password) VALUES (:email, :nom, :password)");

$bindingsInsert = array(
    ':email' => $email,
    ':nom' => $nom,
    ':password' => $hashedPassword,
);

if ($requestInsert->execute($bindingsInsert)) {
    // Récupérer l'ID de l'utilisateur nouvellement inséré
    $userId = $connexion->lastInsertId();

    if ($userId) {
        // L'inscription a réussi, renvoyer l'ID de l'utilisateur enregistré
        $retour["success"] = true;
        $retour["userId"] = $userId;
        $retour["message"] = "Utilisateur enregistré avec succès.";
    } else {
        // Impossible de récupérer l'ID de l'utilisateur, erreur
        $retour["success"] = false;
        $retour["error"] = "Impossible de récupérer l'ID de l'utilisateur.";
    }
} else {
    // Erreur lors de l'insertion de l'utilisateur
    $retour["success"] = false;
    $retour["error"] = "Erreur lors de l'insertion de l'utilisateur.";
}

// Envoi de la réponse JSON
echo json_encode($retour);
?>
