
import React from 'react';
import { View, FlatList, ActivityIndicator, StyleSheet, Text, Image, TouchableOpacity } from 'react-native';

const CustomFlatList = ({ data, renderItem, keyExtractor, titles, setPage, itemStyle, selectedKeys, hasMore, navigation, PageName }) => {

    const renderHeader = () => (
        <View>
        <View style={styles.headerContainer}>
            {titles.map((title, index) => (
                <Text key={index} style={[styles.headerTitle, styles.headerTitleBackground]}>{title}</Text>
            ))}
        </View>
        </View>
    );

    const updatedRenderItem = ({ item }) => (
        <TouchableOpacity onPress={() => navigation.navigate(PageName[0], { selectedItem: item })}>
            <View style={styles.card}>
                {selectedKeys.map((key, index) => (
                    <View key={index} style={styles.cardContent}>
                        {key.includes('image') && item[key] ? (
                            <Image source={{ uri: `https://sites.freeboxos.fr${item[key]}` }} style={styles.image} />
                        ) : (
                            <Text style={[styles.text, itemStyle]}>
                                {key.includes('frais') || key.includes('Montant') || key.includes('montantTotal') 
                                    ? `${item[key]} €` 
                                    : key.includes('niveauCarburant') 
                                    ? `${item[key]} %` 
                                    : item[key]}
                            </Text>
                        )}
                    </View>
                ))}
            </View>
        </TouchableOpacity>
    );
    
    const handleEndReached = () => {
        if (hasMore) {
            setPage(prevPage => prevPage + 1);
        }
    };

    return (
        <FlatList
            data={data}
            keyExtractor={keyExtractor}
            renderItem={updatedRenderItem}
            onEndReached={handleEndReached}
            onEndReachedThreshold={0.5}
            ListHeaderComponent={renderHeader}
            ListFooterComponent={hasMore && <ActivityIndicator size="large" color="#0080FF" style={{ marginVertical: 20 }} />}
            contentContainerStyle={{ flexGrow: 1, padding: 10 }}
        />
    );
};

const styles = StyleSheet.create({
    headerContainer: {
        flexDirection: 'row',
        marginBottom: 10,
        shadowColor: '#58A681',
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.1,
        shadowRadius: 8,
        elevation: 2,
        borderRadius: 10,
        overflow: 'hidden', // Ensures children adhere to borderRadius
    },
    headerTitle: {
        flex: 1,
        fontWeight: 'bold',
        fontSize: 14,
        color: '#fff',
        textAlign: 'center',
        paddingVertical: 10,
    },
    headerTitleBackground: {
        backgroundColor: '#58A681',
       
    },
    card: {
        flexDirection: 'row',
        alignItems: 'center',
        backgroundColor: '#fff',
        borderRadius: 10,
        padding: 10,
        marginVertical: 5,
        marginHorizontal: 5,
        shadowColor: '#000',
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.1,
        shadowRadius: 8,
        elevation: 2,
        overflow: 'hidden',
    },
    cardContent: {
        flex: 1,
        alignItems: 'center',
      
    },
    text: {
        fontSize: 10,
        color: '#333',
        textAlign: 'center',
        marginVertical: 5,  
       
    },
    image: {
        width: 55,
        height: 55,
        borderRadius: 10,
        marginVertical: 5,  // Marge verticale (haut et bas)
    
      },
      
});

export default CustomFlatList;
