import React, { useState } from 'react';
import { TouchableOpacity, Text, View, StyleSheet } from 'react-native';
import DateTimePicker from '@react-native-community/datetimepicker';

const DatePicker = ({ value, onChange }) => {
    const [showDatePicker, setShowDatePicker] = useState(false);

    const handleDateChange = (event, selectedDate) => {
        setShowDatePicker(false);
        if (selectedDate) {
            onChange(selectedDate);
        }
    };

    const handleShowDatePicker = () => {
        setShowDatePicker(true);
    };

    return ( 
        <View style={styles.container}>
            <TouchableOpacity onPress={handleShowDatePicker}>
                <Text style={styles.dateText}>{value.toDateString()}</Text>
            </TouchableOpacity>
            {showDatePicker && (
                <DateTimePicker
                    value={value}
                    mode="date"
                    display="default"
                    onChange={handleDateChange}
                />
            )}
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        
        justifyContent: 'center',
        alignItems: 'center',
        flexDirection: 'row',
        alignItems: 'center',
        backgroundColor: '#eaeaea', // Couleur de fond
        padding: 10,
        borderRadius: 8, // Bords arrondis
        shadowColor: '#000',
        shadowOffset: {
            width: 0,
            height: 2,
        },
        shadowOpacity: 0.25,
        shadowRadius: 3.84,
        elevation: 5,
    },
    dateText: {
        fontSize: 18,
        fontWeight: 'bold',
        marginRight: 10,
    },
});

export default DatePicker;

