import React, { useState, useEffect } from 'react';
import { View, StyleSheet, Alert, ScrollView } from 'react-native';
import InputText from '../../Components/InputText';
import Boutton from '../../Components/Boutton';
import Header from '../../Components/Header';
import DropDown from '../../Components/DropDown';
import DatePicker from '../../Components/DatePicker';
import PhotoSelector from '../../Components/PhotoSelector'; 
import CameraSelector from '../../Components/CameraSelector'; 
import SelectedImage from '../../Components/SelectedImage';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour ajouter un accident
const AjoutAccident = ({ navigation }) => {

    const [NumeroConstat, setNumeroConstat] = useState('');
    const [idAssurance, setIdAssurance] = useState('');
    const [idClient, setIdClient] = useState('');
    const [vehicules, setVehicules] = useState([]);
    const [assurances, setAssurances] = useState([]);
    const [clients, setClients] = useState([]);
    const [selectedVehicule, setSelectedVehicule] = useState(null);
    const [selectedImage, setSelectedImage] = useState(null);
    const [date, setDate] = useState(new Date());
   

    // Récupérer les véhicules, les assurances et les clients lors du chargement du composant
    useEffect(() => {
        fetchAllVehicules();
        fetchAllAssurances();
        fetchAllClients();
    }, []);


// Fonction pour récupérer les véhicules
const fetchAllVehicules = async () => {
    try {
        let allVehicules = [];
        let currentPage = 1;
        let morePages = true;

        while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
                allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                currentPage++;
                morePages = currentPage <= json.totalPages;
            } else {
                console.error(json.message || json.error);
                break;
            }
        }

        setVehicules(allVehicules);
    } catch (error) {
        Alert.alert('Une erreur est survenue lors de la récupération des véhicules.');
    }
};

// Fonction pour récupérer tous les clients
const fetchAllClients = async () => {
    try {
      let allClients = [];
      let currentPage = 1;
      let morePages = true;

      while (morePages) {
        const response = await fetch(
          `https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`
        );
        const json = await response.json();
        if (json.success) {
          allClients = [
            ...allClients,
            ...json.clients.map((client) => ({
              label: `${client.idClient} - ${client.nom}`,
              value: client.idClient,
            })),
          ];
          currentPage++;
          morePages = currentPage <= json.totalPages;
        } else {
          console.error(json.message || json.error);
          break;
        }
      }

      setClients(allClients);
    } catch (error) {
        Alert.alert("Une erreur est survenue lors de la récupération des clients.");
    }
  };



   // Fonction pour récupérer toutes les assurances
const fetchAllAssurances = async () => {
    try {
        let allAssurances = [];
        let currentPage = 1;
        let morePages = true;

        while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/getAssurances.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
                allAssurances = [
                    ...allAssurances,
                    ...json.assurances.map(assurance => ({
                        label: `${assurance.idAssurance} - ${assurance.nomAssurance}`,
                        value: assurance.idAssurance,
                    })),
                ];
                currentPage++;
                morePages = currentPage <= json.totalPages;
            } else {
                console.error(json.message || json.error);
                break;
            }
        }

        setAssurances(allAssurances);
    } catch (error) {
       Alert.alert('Une erreur est survenue lors de la récupération des assurances.');
    }
};


    // Fonction pour ajouter un accident
    const FonctionAjoutAccident = async () => {
        const formattedDate = `${date.getFullYear()}-${('0' + (date.getMonth() + 1)).slice(-2)}-${('0' + date.getDate()).slice(-2)}`;
        const filename = NumeroConstat.replace(/\s+/g, '_') + '.jpeg';
        const localUri = selectedImage;
        try {
            // Validation des champs
            if (!NumeroConstat || !selectedVehicule || !date || !idAssurance || !idClient || !selectedImage) {
                Alert.alert('Veuillez remplir correctement les champs');
                return;
            }

            // Création du formulaire
            const formData = new FormData();
            formData.append('image', { uri: localUri, name: filename + '.jpeg', type: 'image/jpeg' });
            formData.append("NumeroConstat", NumeroConstat);
            formData.append("selectedVehicule", selectedVehicule);
            formData.append("date", formattedDate);
            formData.append("idAssurance", idAssurance);
            formData.append("idClient", idClient);

            const response = await fetch('https://sites.freeboxos.fr/Api/Administratif/insertAccident.php', {
                method: 'POST',
                body: formData,
            });
            const json = await response.json();
            if (json.success) {
                Alert.alert('Accident ajouté avec succès');

                setNumeroConstat('');
                setSelectedVehicule('');
                setDate(new Date());
                setIdAssurance('');
                setIdClient('');
                setSelectedImage(null);
               navigation.navigate('Administratifs');
            } else {
                console.error(json.message || json.error);
            }
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de l\'ajout de l\'accident.');
        }
    }

   

    return (
        <ScrollView>
            <Header title="Ajout d'un accident" />
            <View style={styles.container}>
                <Text style={styles.label}>Numéro du constat</Text>
                <InputText value={NumeroConstat} onChangeText={setNumeroConstat} placeholder="Numéro du constat" />

                <DropDown
                    data={vehicules}
                    onSelect={value => setSelectedVehicule(value)}
                    placeholder="Sélectionnez un véhicule"
                   
                />

                <DatePicker value={date} onChange={setDate} />

                <DropDown
                    data={assurances}
                    onSelect={value => setIdAssurance(value)}
                    placeholder="Sélectionnez une assurance"
              
                />
                <DropDown
                    data={clients}
                    onSelect={value => setIdClient(value)}
                    placeholder="Sélectionnez un client"
                 
                />

<View style={styles.dataContainer}>
                {/* Image  galerie */}  
                <PhotoSelector onSelectImage={setSelectedImage} /> 

                   {/* Image  apareil photo */}
                <CameraSelector onSelectImage={setSelectedImage} /> 

                       {/* Afficher l'image sélectionnée si elle existe */}
                {selectedImage && <SelectedImage uri={selectedImage} />}

                    {/* Boutton */}
                <Boutton style={styles.Boutton} onPress={FonctionAjoutAccident} value="Ajouter l'accident" />
                </View> 
            </View>
            <Footer />
        </ScrollView>
    );
}

const styles = StyleSheet.create({
    container: {
        padding: 20,
        backgroundColor: '#fff',
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
      },
    formGroup: {
        marginBottom: 20,
    },
    label: {
        fontSize: 18,
        marginBottom: 5,
    },
  
});

export default AjoutAccident;
