import React, { useState, useEffect } from 'react';
import { View, StyleSheet, Alert, ScrollView } from 'react-native';
import InputText from '../../Components/InputText';
import Boutton from '../../Components/Boutton';
import Header from '../../Components/Header';
import DropDown from '../../Components/DropDown';
import DatePicker from '../../Components/DatePicker';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

    const AjoutAssurances = ({ navigation }) => {
    const [nomAssurance, setNomAssurance] = useState('');
    const [numeroPolice, setNumeroPolice] = useState('');
    const [fraisAssurance, setFraisAssurance] = useState('');
    const [contact, setContact] = useState('');
    const [selectedVehicule, setSelectedVehicule] = useState(null);
    const [vehicules, setVehicules] = useState([]);
    const [date, setDate] = useState(new Date()); 
   
     

   // Récupérer les véhicules lors du chargement du composant
   useEffect(() => {
    fetchAllVehicules();
}, []);

// Fonction pour récupérer les véhicules
const fetchAllVehicules = async () => {
    try {
        let allVehicules = [];
        let currentPage = 1;
        let morePages = true;

        while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
                allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                currentPage++;
                morePages = currentPage <= json.totalPages;
            } else {
                Alert.alert(json.message || json.error);
                break;
            }
        }

        setVehicules(allVehicules);
    } catch (error) {
        Alert.alert('Une erreur est survenue lors de la récupération des véhicules.');
    }
};

// Fonction pour ajouter une assurance
    const FonctionAjoutAssurance = async () => {
        const formattedDateExpiration = `${date.getFullYear()}-${('0' + (date.getMonth() + 1)).slice(-2)}-${('0' + date.getDate()).slice(-2)}`;
        try {
            // Validation des champs
            if (!nomAssurance || !date || !numeroPolice || !fraisAssurance || !contact || !selectedVehicule) {
                Alert.alert('Veuillez remplir correctement les champs');
                return;
            }

            // Création du formulaire
            const formData = new FormData();
            formData.append("nomAssurance", nomAssurance);
            formData.append("dateExpiration", formattedDateExpiration);
            formData.append("numeroPolice", numeroPolice);
            formData.append("fraisAssurance", fraisAssurance);
            formData.append("contact", contact);
            formData.append("selectedVehicule", selectedVehicule);

            // Envoi du formulaire à l'API
            const response = await fetch('https://sites.freeboxos.fr/Api/Administratif/insertAssurance.php', {
                method: 'POST',
                body: formData,
                headers: {
                    "Content-Type": "multipart/form-data"
                },
            });

            const json = await response.json();
            // Si l'ajout est réussi
            if (json.success) {
                // Réinitialisation des champs du formulaire
                setNomAssurance('');
                setDate(new Date()); // Réinitialiser la date d'expiration à la date actuelle
                setNumeroPolice('');
                setFraisAssurance('');
                setContact('');
                setSelectedVehicule(null);
                navigation.navigate('Administratifs');
                Alert.alert('L\'assurance a été ajoutée avec succès.');
            } else {
                Alert.alert('Erreur lors de l\'ajout de l\'assurance. Veuillez réessayer.');
            }
        } catch (error) {
            Alert.alert('Erreur lors de l\'ajout de l\'assurance. Veuillez réessayer.'); 
        }
    };



    return (
        <ScrollView contentContainerStyle={styles.container}>
            <Header title="Ajout d'une assurance" />

            {/* Sélection du véhicule */}
     <DropDown
     data={vehicules}
     onSelect={value => setSelectedVehicule(value)}
     placeholder="Sélectionnez un véhicule"
   
 />
            {/* Autres champs pour l'assurance */}
        <View style={styles.formGroup}>
                <Text style={styles.label}>Nom de l'assurance</Text>
                <InputText value={nomAssurance} onChangeText={setNomAssurance} placeholder="Nom de l'assurance" />
            </View>
            
            {/* Date d'expiration */}
          
            <DatePicker value={date} onChange={setDate} />


            <View style={styles.formGroup}>
                <Text style={styles.label}>Numéro de police</Text>
                <InputText value={numeroPolice} onChangeText={setNumeroPolice} placeholder="Numéro de police" />
            </View>
            <View style={styles.formGroup}>
                <Text style={styles.label}>Frais d'assurance</Text>
                <InputText value={fraisAssurance } onChangeText={setFraisAssurance} placeholder="Frais d'assurance" />
            </View>
            <View style={styles.formGroup}>
                <Text style={styles.label}>Contact</Text>
                <InputText value={contact} onChangeText={setContact} placeholder="Contact" />
            </View>

            {/* Bouton d'ajout de l'assurance */}
            <Boutton value="Ajouter l'assurance" onPress={FonctionAjoutAssurance} style={styles.Boutton} />
            <Footer />
        </ScrollView>
    );
}

const styles = StyleSheet.create({
    container: {
        padding: 20,
        backgroundColor: '#fff',
    },
    formGroup: {
        marginBottom: 20,
    },
    label: {
        fontSize: 18,
        marginBottom: 5,
    },
  
});

export default AjoutAssurances;
