import React, { useState, useEffect } from 'react';
import {  StyleSheet, Alert, ScrollView,View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native';
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import InputText from '../../Components/InputText';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'une assurance
const AssurancesDetails = ({ route }) => {
const { selectedItem } = route.params;
const navigation = useNavigation();
const [numeroPolice, setNumeroPolice] = useState(selectedItem.NumeroPolice);
const [Date, setDate] = useState(selectedItem.dateExpiration);
const [idAssurance, setIdAssurance] = useState(selectedItem.idAssurance);
const [idVehicule, setIdVehicule] = useState(selectedItem.idVehicule);
const [vehicules, setVehicules] = useState([]);
const[fraisAssurance, setFraisAssurance] = useState(selectedItem.fraisAssurance);
const[contact , setContact] = useState(selectedItem.contact);
const[nomAssurance, setNomAssurance] = useState(selectedItem.nomAssurance);

 


    useEffect(() => {
        fetchAllVehicules();
    }, []);



   // Fonction pour récupérer les véhicules
   const fetchAllVehicules = async () => {
    try {
        let allVehicules = [];
        let currentPage = 1;
        let morePages = true;

        while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
                allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                currentPage++;
                morePages = currentPage <= json.totalPages;
            } else {
                console.error(json.message || json.error);
                break;
            }
        }

        setVehicules(allVehicules);
    } catch (error) {
        Alert.alert('Une erreur est survenue lors de la récupération des véhicules.');
    }
};


// Fonction pour modifier un élément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idAssurance', idAssurance);
            formData.append('numeroPolice', numeroPolice);
            formData.append('dateExpiration', Date);
            formData.append('idVehicule', idVehicule);
            formData.append('fraisAssurance', fraisAssurance);
            formData.append('contact', contact);
            formData.append('nomAssurance', nomAssurance );
      
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/updateAssurance.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Administratifs');
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un élément
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idAssurance', selectedItem.idAssurance);
    
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/supprAssurance.php`, {
                method: 'POST',
                body: formData,
            });
    
            if (response.ok) {
                const data = await response.json();
    
                if (data.success) {
                    // Suppression réussie
                    navigation.navigate('Administratifs');
                    Alert.alert('Succès', data.message);
                } else {
                    // Afficher un message d'erreur
                    Alert.alert('Erreur', data.message);
                }
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };
    


    return (
        <ScrollView>
            <Header title="Détails de l'Assurance" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID de l'asssurance : {selectedItem.idAssurance}</Text>
            
            <Text>Numero de Constat:</Text>
            <InputText
                style={styles.input}
                value={numeroPolice}
                onChangeText={setNumeroPolice}
            />

               <DropDown
                    data={vehicules}
                    onSelect={value => setSelectedVehicule(value)}
                    placeholder="Sélectionnez un véhicule"
                    selectedValue={selectedItem.idVehicule}
                />
          
            <Text> Frais de l'Assurance :</Text>
            <InputText
    value={`${fraisAssurance} €`}
    onChangeText={text => {
        // Assurez-vous de filtrer le texte pour ne garder que les chiffres
        const numericValue = text.replace(/[^0-9.]/g, '');
        setFraisAssurance(numericValue);
    }}
/>

            <Text> Date de l'Asssurance :</Text>
            <InputText
                style={styles.input}
                value={Date}
                onChangeText={setDate}
            />
           
            <Text> Contact : </Text>
            <InputText
                style={styles.input}
                value={contact}
                onChangeText={setContact}
            />
          <Text> Nom de l'asssurance : </Text>
            <InputText
                style={styles.input}
                value={nomAssurance}
                onChangeText={setNomAssurance}
            />
       
       <View style={styles.dataContainer}>
            <BouttonConfirme value="Modifier" onPress={handleEditItem} />
            <BouttonConfirme value="Supprimer" onPress={handleDeleteItem} />
            </View>
            <Footer />
        </ScrollView>
    );
};
    const styles = StyleSheet.create({
        title: {
            fontSize: 24,
            fontWeight: 'bold',
            textAlign: 'center',
            marginVertical: 20,
        },
        dataContainer: {
            flexDirection: 'row',
            flexWrap: 'wrap',
            justifyContent: 'center',
          },
    });

    export default AssurancesDetails;