import React, { useEffect, useState } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

const ListeAssurances = ({ navigation }) => {
    const [assurances, setAssurances] = useState([]);
    const [page, setPage] = useState(1);
    const [hasMore, setHasMore] = useState(true);
    const [totalPages, setTotalPages] = useState(0);
    const PageName = ['AssurancesDetails'];

    useEffect(() => {
        fetchAssurances();
    }, [page]);

    // Fonction pour récupérer les assurances
       const fetchAssurances = () => {
        fetch(`https://sites.freeboxos.fr/Api/Administratif/getAssurances.php?page=${page}`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    setAssurances(prevAssurances => [...prevAssurances, ...json.assurances]);

                    setTotalPages(json.totalPages);
                    setHasMore(page < json.totalPages);
        } else {
            Alert.alert(json.message || json.error);
        }
    })
    .catch((error) => console.error(error))
};

const keyExtractor = (item, index) => index.toString();
const titles = ["Nom", "Date", "Numéro", "Frais", "Contact", "Marque", "Modele", "Immatriculation"];
    const renderItem = ({ item }) => (
        <View >
            {item.nomAssurance}
            {item.dateExpiration}
            {item.NumeroPolice}
            {item.fraisAssurance}
            {item.contact}
            {item.nom_marque}
            {item.nom_modele}
            {item.Immat}
        </View>
    );

    return (
        <View style={styles.container}>
            <Header title="Liste des Assurances" />
        
            
            <CustomFlatList
                data={assurances}
                renderItem={renderItem}
                keyExtractor={keyExtractor}
                titles={titles}
                setPage={setPage}
                selectedKeys={['nomAssurance', 'dateExpiration', 'NumeroPolice', 'fraisAssurance', 'contact', 'nom_marque', 'nom_modele', 'Immat']} 
                hasMore={hasMore}
                navigation={navigation}
                PageName={PageName}
            />
            <Boutton title="Ajouter une assurance" onPress={() => navigation.navigate('AjoutAssurances')} value= 'Ajouter' />
          <Footer />
        </View>
    );
};
const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
   dataContainer: {
            flexDirection: 'row',
            flexWrap: 'wrap',
            justifyContent: 'center',
          },
});
export default ListeAssurances;
