import React, { useState, useEffect } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

const ListeCharges = ({ navigation }) => {
    const [charges, setCharges] = useState([]);
    const [page, setPage] = useState(1);
    const [hasMore, setHasMore] = useState(true);
    const [totalPages, setTotalPages] = useState(0);
    const PageName = ['ChargeDetails'];

    useEffect(() => {
        fetchListeCharges();
    }, [page]);

  

    const fetchListeCharges = () => {
        fetch(`https://sites.freeboxos.fr/Api/Vehicules/getSuplementsVehicules.php?page=${page}`)
        .then((response) => response.json())
        .then((json) => {
            if (json.success) {
                setCharges(prevCharges => [...prevCharges, ...json.charges]);
                setTotalPages(json.totalPages);
                setHasMore(page < json.totalPages);
            } else {
                Alert.alert(json.message || json.error);
            }
        })
        .catch((error) => console.error(error));
    };


    const keyExtractor = (item, index) => index.toString();
    const titles = ["Numéro du suppléments", "Suppléments","Frais", "Description",  "Civilié",  "Nom client", "Marque", "Modele", "Immatriculation"];
    const renderItem = ({ item }) => (
        <View>
            {item.idSupplementsVehicule}
            {item.nom}
            {item.frais}
            {item.description}
            {item.Genre_Client}
            {item.Nom_Client}
            {item.Nom_Marque}
            {item.Nom_Modele}
            {item.Immatriculation_Vehicule}
        </View>
    );
    
    return (
        <View style={styles.container}>
            <Header title="Liste des supplements en cours" />
          
            <CustomFlatList
                data={charges}
                renderItem={renderItem}
                keyExtractor={keyExtractor}
                titles={titles}
                setPage={setPage}
                selectedKeys={['idSupplementsVehicule','nom',  'frais', 'description', 'Genre_Client', 'Nom_Client', 'Nom_Marque', 'Nom_Modele', 'Immatriculation_Vehicule']} 
                hasMore={hasMore}
                navigation={navigation}
                PageName={PageName}
            />
              <Boutton title="Ajouter un supplément" onPress={() => navigation.navigate('AjoutCharge')} value='Ajouter' />
            <Footer />
        </View>
    );
};
    
const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
});

export default ListeCharges;
