import React, { useState, useEffect } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

// Fonction pour afficher la liste des check de véhicule
const ListeCheckVehicule = ({ navigation }) => {
    const [etats, setEtats] = useState([]);
    const [page, setPage] = useState(1);
    const [hasMore, setHasMore] = useState(true);
    const [totalPages, setTotalPages] = useState(0);
    const PageName = ['CheckVehiculeDetails'];

    useEffect(() => {
        fetchEtats();
    }, [page]);

    // Fonction pour récupérer les etats
    const fetchEtats = () => {

        fetch(`https://sites.freeboxos.fr/Api/Vehicules/getEtats.php?page=${page}`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    setEtats(prevEtats => [...prevEtats, ...json.etats]);
                    setTotalPages(json.totalPages);
                    setHasMore(page < json.totalPages);
                 
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };

    const keyExtractor = (item, index) => index.toString();
    const titles = [ "Civilié", "Nom du client", "Marque", "Modele", "Immatriculation", "checkIn", "checkOut", "imageEtat"];
        
        const renderItem = ({ item }) => (
            <View >
            
                {item.Genre_Client}
                {item.Nom_Client}
                {item.Nom_Marque}
                {item.Nom_Modele}
                {item.Immatriculation_Vehicule}
                {item.checkIn}
                {item.checkOut}
                {item.imageEtat}
             
            </View>
        );

        
        return (
            <View style={styles.container}>
                <Header title="Liste des check " />
                
                <CustomFlatList
                    data={etats}
                    renderItem={renderItem}
                    keyExtractor={keyExtractor}
                    titles={titles}
                    setPage={setPage}
                    selectedKeys={['Genre_Client', 'Nom_Client', 'Nom_Marque', 'Nom_Modele', 'Immatriculation_Vehicule','checkIn', 'checkOut', 'imageEtat']} 
                    hasMore={hasMore}
                    PageName={PageName}
                    navigation={navigation}

                />
                <Boutton title="Ajouter un check" onPress={() => navigation.navigate('AjoutCheckVehicule')} value='Ajouter' />
                <Footer />
            </View>
        );
    };

const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },

   
});

export default ListeCheckVehicule;
