import React, { useState, useEffect } from 'react';
import { StyleSheet, Alert, ScrollView, View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; 
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import InputText from '../../Components/InputText';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

const ClientDetails = ({ route }) => {
    const { selectedItem } = route.params;
    const [idClient, setidClient] = useState(selectedItem.idClient);
    const [editedClientNom, setEditedClientNom] = useState(selectedItem.nom);
    const [editedClientPrenom, setEditedClientPrenom] = useState(selectedItem.prenom);
    const [editedClientAdresse, setEditedClientAdresse] = useState(selectedItem.adresse);
    const [editedEmail, setEditedEmail] = useState(selectedItem.email);
    const [editedNumeroTelephone, setEditedNumeroTelephone] = useState(selectedItem.numeroTelephone);
    const [editedVille, setEditedVille] = useState(selectedItem.Ville);
    const [editedCodePostal, setEditedCodePostal] = useState(selectedItem.CodePostale);
    const [selectedGenre, setSelectedGenre] = useState(selectedItem.idGenre);
    const [genres, setGenres] = useState([]);
    const navigation = useNavigation();

    useEffect(() => {
        fetchGenres();
    }, []);

    // Fonction pour récupérer les genres
    const fetchGenres = async () => {
        try {
            const response = await fetch('https://sites.freeboxos.fr/Api/Listes/getGenre.php');
            const json = await response.json();
            if (json.success) {
                setGenres(json.genres.map(Genre => ({ label: `${Genre.Genre}`, value: Genre.idGenre })));
            } else {
                Alert.alert(json.message || json.error);
            }
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des genres');
        } 
    };

    // Fonction pour modifier un élément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idClient', idClient);
            formData.append('Nom', editedClientNom);
            formData.append('Prenom', editedClientPrenom);
            formData.append('Adresse', editedClientAdresse);
            formData.append('Email', editedEmail);
            formData.append('NumeroTelephone', editedNumeroTelephone);
            formData.append('Ville', editedVille);
            formData.append('CodePostal', editedCodePostal);
            formData.append('idGenre', selectedGenre);
         
            const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/updateClient.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Clients');
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un élément
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idClient', selectedItem.idClient);
            const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/supprClient.php`, {
                method: 'POST',
                body: formData,
            });
    
            if (response.ok) {
                const data = await response.json();
                navigation.navigate('Clients');
                Alert.alert('Succès', data.message);
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };

    return (
        <ScrollView>
            <Header title="Détails du client" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du Client : {selectedItem.idClient}</Text>
      
            <DropDown
                data={genres}
                onSelect={value => setSelectedGenre(value)}
                placeholder="Sélectionnez une civilité"
                selectedValue={selectedGenre}
            />

            <Text>Nom : {selectedItem.nom}</Text>
            <InputText
                value={editedClientNom}
                onChangeText={setEditedClientNom}
            />

            <Text>Prénom : {selectedItem.prenom}</Text>
            <InputText
                value={editedClientPrenom}
                onChangeText={setEditedClientPrenom}
            />

            <Text>Adresse : {selectedItem.adresse}</Text>
            <InputText
                value={editedClientAdresse}
                onChangeText={setEditedClientAdresse}
            />

            <Text>Email : {selectedItem.email}</Text>
            <InputText
                value={editedEmail}
                onChangeText={setEditedEmail}
            />

            <Text>Numéro de téléphone : {selectedItem.numeroTelephone}</Text>
            <InputText
                value={editedNumeroTelephone}
                onChangeText={setEditedNumeroTelephone}
            />

            <Text>Ville : {selectedItem.Ville}</Text>
            <InputText
                value={editedVille}
                onChangeText={setEditedVille}
            />

            <Text>Code Postal : {selectedItem.CodePostal}</Text>
            <InputText
                value={editedCodePostal}
                onChangeText={setEditedCodePostal}
            />
               <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
        </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
      },
});

export default ClientDetails;
