import React, { useEffect, useState } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

const ListeClients = ({ navigation }) => {
    const [clients, setClients] = useState([]);
    const [page, setPage] = useState(1);
    const [hasMore, setHasMore] = useState(true);
    const [totalPages, setTotalPages] = useState(0);
    const PageName = ['ClientDetails'];

    useEffect(() => {
        fetchClients();
    }, [page]);

 

    // Fonction pour récupérer les clients
    const fetchClients = async () => {
        fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${page}`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    // Vérifier si les nouveaux clients ne sont pas déjà présents dans la liste
                    const uniqueClients = json.clients.filter(newClient => !clients.some(existingClient => existingClient.id === newClient.id));
                    // Ajoute uniquement les nouveaux clients à la liste existante
                    setClients(prevClients => [...prevClients, ...uniqueClients]);
                    setTotalPages(json.totalPages);
                    setHasMore(page < json.totalPages);
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error))
    };

    const keyExtractor = (item, index) => index.toString();
    const titles = ["Civilité", "Nom du client", 'Prénom du client', "Email", "Adresse", "Numéro téléphone", "Ville", "Code postale"];

    const renderItem = ({ item }) => (
        <View>
            {item.Genre}
            {item.nom}
            {item.prenom}
            {item.email}
            {item.adresse}
            {item.numeroTelephone}
            {item.Ville}
            {item.CodePostale}
        </View>
    );

    return (
        <View style={styles.container}>
            <Header title="Liste des clients" />
            <CustomFlatList
                data={clients}
                renderItem={renderItem}
                keyExtractor={keyExtractor}
                titles={titles}
                setPage={setPage}
                selectedKeys={['Genre', 'nom', 'prenom', 'email', 'adresse', 'numeroTelephone', 'Ville', 'CodePostale']}
                hasMore={hasMore} // Passe hasMore comme prop
                navigation={navigation}
                PageName={PageName} // Passe le nom de la page en tant que prop
            />
            <Boutton onPress={() => navigation.navigate('AjoutClient')} value="ajouter" />
                <Footer />
        </View>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
});

export default ListeClients;
