import React, { useState, useEffect } from 'react';
import { StyleSheet, Alert, ScrollView, View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; 
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import InputText from '../../Components/InputText';
import PDFGenerator from '../../Components/PDFGenerator';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'un contrat
const ContratDetails = ({ route }) => {
    const { selectedItem } = route.params;
    const [idcontrat, setIdContrat] = useState(selectedItem.idContrat);
    const [selectedVehicule, setSelectedVehicule] = useState(selectedItem.idVehicule); 
    const [montantTotal, setMontantTotal] = useState(selectedItem.montantTotal); 
    const [selectedClient, setSelectedClient] = useState(selectedItem.idClient);
    const [dateDebut, setDateDebut] = useState(selectedItem.dateDebut);
    const [dateFin, setDateFin] = useState(selectedItem.dateFin);
    const [vehicules, setVehicules] = useState([]);
    const [clients, setClients] = useState([]);
    const [vehiculeMake, setVehiculeMake] = useState('');
    const [vehiculeModel, setVehiculeModel] = useState('');
    const [vehiculePlate, setVehiculePlate] = useState('');
    const [nomClient , setNomClient] = useState('');
    const [prenomClient , setPrenomClient] = useState('');
    const [genreClient , setGenreClient] = useState('');
    const navigation = useNavigation();

    useEffect(() => {
        fetchAllVehicules();
        fetchAllClients();
    }, []);

    // Fonction pour récupérer les clients
    const fetchAllClients = async () => {
        try {
            let allClients = [];
            let currentPage = 1;
            let morePages = true;

            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allClients = [...allClients, ...json.clients.map(client => ({
                        label: `${client.idClient}  - ${client.Genre} ${client.nom}`,
                        value: client.idClient,
                        genreclient: client.Genre,
                        nom: client.nom,
                        prenom: client.prenom
                    }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    console.error(json.message || json.error);
                    break;
                }
            }

            setClients(allClients);

            // Si un client est déjà sélectionné, récupérez ses détails
            const selectedClientData = allClients.find(client => client.value === selectedClient);
            if (selectedClientData) {
                setNomClient(selectedClientData.nom);
                setPrenomClient(selectedClientData.prenom);
                setGenreClient(selectedClientData.genreclient);
            }

        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des clients');
        }
    };

    // Fonction pour récupérer les véhicules
    const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;

            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({
                        label: `${vehicule.nom_marque} - ${vehicule.Immat}`,
                        value: vehicule.idVehicule,
                        make: vehicule.nom_marque,
                        model: vehicule.nom_modele,
                        plate: vehicule.Immat
                        
                    }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    console.error(json.message || json.error);
                    break;
                }
            }

            setVehicules(allVehicules);
           
            // Set initial vehicle details based on selectedVehicule
            const initialVehicle = allVehicules.find(v => v.value === selectedVehicule);
            if (initialVehicle) {
                setVehiculeMake(initialVehicle.make);
                setVehiculeModel(initialVehicle.model);
                setVehiculePlate(initialVehicle.plate);
            }
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des véhicules');
        }
    };

    // Fonction pour modifier un contrat
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idContrat', idcontrat);
            formData.append('idVehicule', selectedVehicule);
            formData.append('idClient', selectedClient);
            formData.append('dateDebut', dateDebut);
            formData.append('dateFin', dateFin);
            formData.append('montantTotal', montantTotal);


            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/updateContrat.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Administratifs');
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un contrat
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idcontrat', idcontrat);
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/supprContrat.php`, {
                method: 'POST',
                body: formData,
            });
    
            if (response.ok) {
                const data = await response.json();
                navigation.navigate('Administratifs');
               
                Alert.alert('Succès', data.message);
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };

    return (
        <ScrollView>
            <Header title="Détails du contrat" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du Contrat : {idcontrat}</Text>
      
            <DropDown
                data={vehicules}
                onSelect={value => {
                    setSelectedVehicule(value);
                    const selectedVehicle = vehicules.find(v => v.value === value);
                    if (selectedVehicle) {
                        setVehiculeMake(selectedVehicle.make);
                        setVehiculeModel(selectedVehicle.model);
                        setVehiculePlate(selectedVehicle.plate);
                    }
                }}
                placeholder="Sélectionnez un véhicule"
                selectedValue={selectedVehicule}
            />
            <DropDown   
                data={clients}
                onSelect={value => setSelectedClient(value)}
                placeholder="Sélectionnez un client"
                selectedValue={selectedClient}
            />
            <Text>Date de début :</Text>
            <InputText
                value={dateDebut}
                onChangeText={setDateDebut}
            />
            <Text>Date de fin :</Text>
            <InputText
                value={dateFin}
                onChangeText={setDateFin}
            />

            <InputText
                value={`${montantTotal} €`}
                onChangeText={text => {
                    // Assurez-vous de filtrer le texte pour ne garder que les chiffres
                    const numericValue = text.replace(/[^0-9.]/g, '');
                    setMontantTotal(numericValue);
                }}
            />

            <View style={styles.dataContainer}>

            <PDFGenerator
    documentData={{
        NumeroContrat: idcontrat,
        Vehicule: `${vehiculeMake} ${vehiculeModel}  ${vehiculePlate}`,
        Client: `${genreClient} ${nomClient}  ${prenomClient} `,   
        montantTotal: `${montantTotal} €`,
        dateDebut: dateDebut,
        dateFin: dateFin,
    }}
    documentType="Contrat"
/>



                            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
                <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
});

export default ContratDetails;
