import React, { useEffect, useState } from 'react';
import {View,  StyleSheet, Alert} from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

const ListeContrats = ({navigation}) => {
    const [contrats, setContrats]= useState([]);
    const [page, setPage] = useState(1);
    const [hasMore, setHasMore] = useState(true);
    const [totalPages, setTotalPages] = useState(0); 
    const PageName = ['ContratDetails'];
  
    useEffect(() => {
        fetchContrats();
    }, [page]);

    // Fonction pour récupérer les contrats
    const fetchContrats = () => {
        fetch(`https://sites.freeboxos.fr/Api/Administratif/getContrats.php?page=${page}`)
        .then((response) => response.json())
        .then((json) => {
            if (json.success) {
                setContrats(prevContrats=> [...prevContrats, ...json.contrats]);
                setTotalPages(json.totalPages);
                setHasMore(page < json.totalPages);
             
            } else {
                Alert.alert(json.message || json.error);
            }
        })
        .catch((error) => console.error(error))
    };
  
    const keyExtractor = (item, index) => index.toString();
    const titles = [ 'Marque', "Modèle", "Immatriculation",  "Nom Client", "id Client", "Date début", "Date fin", "Nombre de jours", "Montant total"];
  
        const renderItem = ({ item }) => (                             
                        <View>
                            
                            {item.nom_marque}
                            {item.nom_modele}
                            {item.Immat}
                            {item.nom_client}
                            {item.idClient}
                            {item.dateDebut}
                            {item.dateFin}
                            {item.nombreJours}
                            {item.montantTotal}    
                        </View>
    );


    return (
        <View style={styles.container}>
            <Header title="Liste des contrats" />
          
            <CustomFlatList
                data={contrats}
                renderItem={renderItem}
                keyExtractor={keyExtractor}
                titles={titles}
                setPage={setPage}
                selectedKeys={[  'nom_marque', 'nom_modele', 'Immat', 'nom_client','idClient', 'dateDebut', 'dateFin', 'nombreJours', 'montantTotal']}
                hasMore={hasMore} // Passer hasMore comme prop
                navigation={navigation}
                PageName={PageName}
            />
              <Boutton title="Ajouter un contrat" onPress={() => navigation.navigate('AjoutContrat')} value='Ajouter' />
            <Footer />
        </View>
    );
    };
    const styles = StyleSheet.create({
        container: {
            flex: 1,
            padding: 20,
        },
     
    }); 
            
export default ListeContrats;