import React, { useEffect, useState } from 'react';
import { View, StyleSheet, TouchableOpacity, Image, Text, ScrollView } from 'react-native';
import Header from '../Components/Header';
import DataBox from '../Components/DataBox';
import UserInfo from '../Components/UserInfo';
import userIcon from '../assets/user.png';
import clientsIcon from '../assets/clients.png';
import documentIcon from '../assets/document.png';
import vehiculesIcon from '../assets/vehicules2.png';
import listesIcon from '../assets/listes.png';

export default function Dashboard({ navigation }) {
  const [affaires, setAffaires] = useState([]);
  const [contrats, setContrats] = useState([]);
  const [vehiculesloues, setVehiculesLoues] = useState([]);

  useEffect(() => {
    const fetchContrats = () => {
      fetch(`https://sites.freeboxos.fr/Api/DashBoard/ContratsMois.php`)
        .then((response) => response.json())
        .then((json) => {
          if (json.success) {
            setContrats(json.contrats);
          } else {
            console.error(json.message || json.error);
          }
        })
        .catch((error) => console.error(error));
    };

    const fetchAffaires = () => {
      fetch(`https://sites.freeboxos.fr/Api/DashBoard/ChiffreAffaire.php`)
        .then((response) => response.json())
        .then((json) => {
          if (json.success) {
            setAffaires(json.affaires);
          } else {
            console.error(json.message || json.error);
          }
        })
        .catch((error) => console.error(error));
    };

    const fetchVehiculesLoues = () => {
      fetch(`https://sites.freeboxos.fr/Api/DashBoard/VehiculesLocation.php`)
        .then((response) => response.json())
        .then((json) => {
          if (json.success) {
            setVehiculesLoues(json.vehiculesloues);
          } else {
            console.error(json.message || json.error);
          }
        })
        .catch((error) => console.error(error));
    };

    const fetchData = () => {
      fetchContrats();
      fetchAffaires();
      fetchVehiculesLoues();
    };

    fetchData(); // Fetch data initially
    const intervalId = setInterval(fetchData, 30000); // Fetch data every 30 seconds

    return () => clearInterval(intervalId); // Cleanup interval on component unmount
  }, []);

  const FonctionVersInscription = () => {
    navigation.navigate('RegisterScreen');
  };

  const FonctionVersClients = () => {
    navigation.navigate('Clients');
  };

  const FonctionVersAdministatif = () => {
    navigation.navigate('Administratifs');
  };

  const FonctionVersVehicules = () => {
    navigation.navigate('Vehicules');
  };

  const FonctionVersListes = () => {
    navigation.navigate('Listes');
  };

  const Logout = () => {
    navigation.navigate('HomeScreen');
  };

  const formatAffaires = () => {
    return affaires.map(item => `${item.ChiffreAffaires} €`).join(', ');
  };

  const formatVehiculesLoues = () => {
    const count = vehiculesloues.NombreVehiculesLoues;
    return `Véhicule${count > 1 ? 's' : ''} loué${count > 1 ? 's' : ''}: ${count} véhicule${count > 1 ? 's' : ''}`;
  };

  const formatContrats = () => {
    const count = contrats.NombreContrats;
    return `Contrat${count > 1 ? 's' : ''} en cours: ${count} contrat${count > 1 ? 's' : ''}`;
  };

  return (
    <View style={styles.container}>
      <Header title="Dashboard" />
      <UserInfo />
      <ScrollView>
        <View style={styles.dataContainer}>
          <DataBox
            title="Chiffre d'affaires des véhicules"
            data={formatAffaires()}
            backgroundColor="skyblue"
          />
          <DataBox
            title="Véhicules loués"
            data={formatVehiculesLoues()}
            backgroundColor="green"
          />
          <DataBox
            title="Contrats du mois"
            data={formatContrats()}
            backgroundColor="pink"
          />
        </View>

        <View style={styles.dataContainer}>
          <TouchableOpacity onPress={FonctionVersInscription}>
            <View style={styles.iconContainer}>
              <Image source={userIcon} style={styles.icon} />
              <Text style={styles.iconTitle}>Ajout utilisateur</Text>
            </View>
          </TouchableOpacity>
          <TouchableOpacity onPress={FonctionVersClients}>
            <View style={styles.iconContainer}>
              <Image source={clientsIcon} style={styles.icon} />
              <Text style={styles.iconTitle}>Clients</Text>
            </View>
          </TouchableOpacity>
          <TouchableOpacity onPress={FonctionVersAdministatif}>
            <View style={styles.iconContainer}>
              <Image source={documentIcon} style={styles.icon} />
              <Text style={styles.iconTitle}>Documents</Text>
            </View>
          </TouchableOpacity>
          <TouchableOpacity onPress={FonctionVersVehicules}>
            <View style={styles.iconContainer}>
              <Image source={vehiculesIcon} style={styles.icon} />
              <Text style={styles.iconTitle}>Véhicules</Text>
            </View>
          </TouchableOpacity>
          <TouchableOpacity onPress={FonctionVersListes}>
            <View style={styles.iconContainer}>
              <Image source={listesIcon} style={styles.icon} />
              <Text style={styles.iconTitle}>Listes</Text>
            </View>
          </TouchableOpacity>
        </View>
      </ScrollView>
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    overflow: 'hidden',
    alignItems: 'center',
  },
  dataContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    justifyContent: 'center',
  },
  iconContainer: {
    alignItems: 'center',
    margin: 20,
    borderRadius: 25,
    backgroundColor: 'lightgreen',
    padding: 10,
  },
  icon: {
    width: 30,
    height: 30,
    resizeMode: 'contain',
  },
  iconTitle: {
    marginTop: 10,
    textAlign: 'center',
  },
});

