import React, { useState, useEffect } from 'react';
import {  StyleSheet, Alert,  ScrollView,View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; 
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import InputText from '../../Components/InputText';
import SelectedImageServer from '../../Components/SelectedImageServeur';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'un document client
const DocumentsClientsDetails = ({ route }) => {
    const { selectedItem } = route.params;
    const [selectedClient, setSelectedClient] = useState(selectedItem.idClient);
    const [idDocumentClient, setIdDocumentClient] = useState(selectedItem.idDocumentClient);
    const [NomDocumentClient, setNomDocumentClient] = useState(selectedItem.NomDocumentClient);
    const [selectedImage, setSelectedImage] = useState(selectedItem.imageClient);
    const [clients, setClients] = useState([]);
    const navigation = useNavigation();

    useEffect(() => {
      
        fetchAllClients();
    }, []);


 // Fonction pour récupérer tous les clients
 const fetchAllClients = async () => {
    try {
        let allClients = [];
        let currentPage = 1;
        let morePages = true;

        while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
                allClients = [...allClients, ...json.clients.map(client => ({ label: `${client.idClient}  - ${client.Genre} ${client.nom}`, value: client.idClient }))];
                currentPage++;
                morePages = currentPage <= json.totalPages;
            } else {
                Alert.alert(json.message || json.error);
                break;
            }
        }

        setClients(allClients);
    } catch (error) {
        Alert.alert('Une erreur est survenue lors de la récupération des clients');
    }
};

 
// Fonction pour modifier un document client
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idDocumentClient', idDocumentClient);
            formData.append('idClient', selectedClient);
            formData.append('NomDocumentClient', NomDocumentClient);

            const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/updateDocsClient.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Clients');
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };
    
    // Fonction pour supprimer un document client
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idDocumentClient', idDocumentClient);
          
            const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/supprDocsClient.php`, {
                method: 'POST',
                body: formData,
               
            });
    
            if (response.ok) {
                const data = await response.json();
                navigation.navigate('Clients');
                Alert.alert('Succès', data.message);
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };

    return (
        <ScrollView>
            <Header title="Détails du document Client" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du DocumentsClients : {idDocumentClient}</Text>
      
            <DropDown   
                data={clients}
                onSelect={value => setSelectedClient(value)}
                placeholder="Sélectionnez un client"
                selectedValue={selectedClient}
            />
          
            <Text>Nom : </Text>
            <InputText
                value={NomDocumentClient}
                onChangeText={setNomDocumentClient}
            />
     
            <SelectedImageServer uri={selectedImage} />
            <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
   
  
});

export default DocumentsClientsDetails;
