import React, { useEffect, useState } from 'react';
import { View,  StyleSheet, Alert } from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';  
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

// Fonction pour afficher la liste des documents des clients
const ListeDocumentsClients = ({ navigation }) => {
    const [docsClients, setDocsClients] = useState([]);
    const [page, setPage] = useState(1);
    const [totalPages, setTotalPages] = useState(0);
    const [hasMore, setHasMore] = useState(true);
    const PageName = ['DocumentsClientsDetails'];
    //  Récupérer les documents des clients lors du chargement du composant
    useEffect(() => {
        fetchDocsClients();
    }, [page]);

    // Fonction pour récupérer les documents des clients
    const fetchDocsClients = () => {
       
        fetch(`https://sites.freeboxos.fr/Api/Clients/getDocsClients.php?page=${page}`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    setDocsClients(prevDocsClients => [...prevDocsClients, ...json.docsClients]);
                    setTotalPages(json.totalPages);
                    setHasMore(page < json.totalPages);
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error))
           
    };
// Fonction pour afficher la liste des documents des clients
    const keyExtractor = (item, index) => index.toString();
    const titles = ["Numero du client", "Civilité", "Nom", "Titre document", "Image du document"];

    const renderItem = ({ item }) => (
        <View>
            {item.idClient}
            {item.Genre}
            {item.nom}
            {item.NomDocumentClient}
            {item.imageClient}
        </View>
    );

    return (
        <View style={styles.container}>
            <Header title="Liste des documents clients" />
           
         
                <CustomFlatList
                    data={docsClients}
                    renderItem={renderItem}
                    keyExtractor={keyExtractor}
                    titles={titles}
                    setPage={setPage}
                    selectedKeys={['idClient', 'Genre', 'nom', 'NomDocumentClient', 'imageClient']}
                    hasMore={hasMore} 
                    navigation={navigation}
                    PageName={PageName}
                />
                 <Boutton title="Ajouter un document" onPress={() => navigation.navigate('AjoutClientDocuments')} value='Ajouter' />
            <Footer />
        </View>
    );
};
const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
 
});

export default ListeDocumentsClients;
