import React, { useEffect, useState } from 'react';
import { View, StyleSheet, Alert, ScrollView } from 'react-native';
import InputText from '../../Components/InputText';
import Boutton from '../../Components/Boutton';
import Header from '../../Components/Header';
import PhotoSelector from '../../Components/PhotoSelector'; 
import CameraSelector from '../../Components/CameraSelector'; 
import SelectedImage from '../../Components/SelectedImage';
import DropDown from '../../Components/DropDown';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour ajouter un document véhicule
const AjoutDocumentsVehicule = ({ navigation }) => {
    const [vehicules, setVehicules] = useState([]);
    const [NomDocumentVehicule, setNomDocumentVehicule] = useState('');
    const [selectedVehicule, setSelectedVehicule] = useState('');
    const [selectedImage, setSelectedImage] = useState(null);

   
    // Récupérer les véhicules lors du chargement du composant
    useEffect(() => {
        fetchAllVehicules();
    }, []);
    
    // Fonction pour récupérer les véhicules
    const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    Alert.alert(json.message || json.error);
                    break;
                }
            }
    
            setVehicules(allVehicules);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des véhicules');
        }
    };
    
  // Fonction pour valider l'envoi de l'image
    const validateImage = async () => {
        if (selectedImage && selectedVehicule && NomDocumentVehicule) {
            const localUri = selectedImage; // Obtenez l'URI de l'image
            const filename = NomDocumentVehicule.replace(/\s+/g, '_') + '.jpeg'; // Utilise le nom du document comme nom de fichier avec une extension
            const formData = new FormData();
            formData.append('image', { uri: localUri, name: filename, type: 'image/jpeg' }); // Ajouter l'image à FormData
            formData.append('idVehicule', selectedVehicule); // Ajouter l'id du client à FormData
            formData.append('NomDocumentVehicule', NomDocumentVehicule); // Ajouter le nom du document à FormData   
            try {
                const response = await fetch('https://sites.freeboxos.fr/Api/Vehicules/insertDocsVehicule.php', {
                    method: 'POST',
                    body: formData,
                    headers: {
                        'Content-Type': 'multipart/form-data',
                    },
                });
    
                const data = await response.json();

                // Réinitialiser les états après l'envoi réussi
                setNomDocumentVehicule('');
                setSelectedImage(null);
                setSelectedVehicule('');
                navigation.navigate("Vehicules");
                Alert.alert('Document ajouté avec succès');
            } catch (error) {
                Alert.alert('Erreur lors de l\'envoi de l\'image à l\'API :', error);
            }
        } else {
            Alert.alert('Données manquantes', 'Veuillez sélectionner un client, saisir un nom de document et choisir une image avant de valider.');
        }
    };

    return (
        <ScrollView>
            <Header title="Ajout document Véhicule" />
            <View style={styles.container}>
           
            <DropDown
                    data={vehicules}
                    onSelect={value => setSelectedVehicule(value)}
                    placeholder="Sélectionnez un véhicule"
                />


                    <View style={styles.formGroup}>
                    <Text style={styles.label}>Nom du document:</Text>
                    <InputText label="Nom du document" value={NomDocumentVehicule} onChangeText={setNomDocumentVehicule} />
                </View>
            
                <View style={styles.dataContainer}>
                {/* Image  galerie */}  
                <PhotoSelector onSelectImage={setSelectedImage} /> 

                   {/* Image  apareil photo */}
                <CameraSelector onSelectImage={setSelectedImage} /> 

                       {/* Afficher l'image sélectionnée si elle existe */}
                {selectedImage && <SelectedImage uri={selectedImage} />}


                <View style={styles.buttonContainer}>
                    <Boutton  onPress={validateImage} value="envoyer" />
                </View>
                </View>
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        paddingHorizontal: 20,
        paddingTop: 20,
    },
    formGroup: {
        marginBottom: 20,
    },
    label: {
        marginBottom: 5,
        fontSize: 16,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
    
});

export default AjoutDocumentsVehicule;
