import React, { useState, useEffect } from 'react';
import { StyleSheet, Alert,  ScrollView,View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; 
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import InputText from '../../Components/InputText';
import SelectedImageServer from '../../Components/SelectedImageServeur';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'un document véhicule
const DocumentsVehiculeDetails = ({ route }) => {
    const { selectedItem } = route.params;
   
    const [selectedVehicule, setSelectedVehicule] = useState(selectedItem.idVehicule);
    const [idDocumentVehicule, setIdDocumentVehicule] = useState(selectedItem.idDocumentVehicule);
    const [NomDocumentVehicule, setNomDocumentVehicule] = useState(selectedItem.NomDocumentVehicule);
    const [selectedImage, setSelectedImage] = useState(selectedItem.imageVehicule);
    const [Vehicules, setVehicules] = useState([]);
    const navigation = useNavigation();

    useEffect(() => {
      
        fetchAllVehicules();
    }, []);

    // Fonction pour récupérer les véhicules
    const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;

            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    Alert.alert(json.message || json.error);
                    break;
                }
            }

            setVehicules(allVehicules);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des véhicules');
        }
    };

 
//fonction pour modifier un document véhicule
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idDocumentVehicule', idDocumentVehicule);
            formData.append('idVehicule', selectedVehicule);
            formData.append('NomDocumentVehicule', NomDocumentVehicule);
          
            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/updateDocsVehicule.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate("Vehicules");
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un document véhicule
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idDocumentVehicule', idDocumentVehicule);
            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/supprDocsVehicule.php`, {
                method: 'POST',
                body: formData,
            });
    
            if (response.ok) {
                const data = await response.json();
                navigation.navigate("Vehicules");
                Alert.alert('Succès', data.message);
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };

    return (
        <ScrollView>
            <Header title="Détails du document véhicule" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du DocumentsVehicules : {idDocumentVehicule}</Text>
      
            <DropDown   
                data={Vehicules}
                onSelect={value => setSelectedVehicule(value)}
                placeholder="Sélectionnez un véhicule"
                selectedValue={selectedVehicule}
            />
          
            <Text>Nom : </Text>
            <InputText
                value={NomDocumentVehicule}
                onChangeText={setNomDocumentVehicule}
            />
     
            <SelectedImageServer uri={selectedImage} />
            <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
  
});

export default DocumentsVehiculeDetails;
