// ListeDocumentsVehicule.js

import React, { useEffect, useState } from 'react';
import { View,StyleSheet, Alert } from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

// Fonction pour afficher la liste des documents des véhicules
const ListeDocumentsVehicule = ({ navigation }) => {
    const [docsVehicules, setDocsVehicules] = useState([]);
    const [page, setPage] = useState(1);
    const [totalPages, setTotalPages] = useState(0);
    const [hasMore, setHasMore] = useState(true);
    const PageName = ['DocumentsVehiculeDetails'];
    useEffect(() => {
        fetchDocsVehicules();
    }, [page]);

    // Fonction pour récupérer les documents des véhicules
    const fetchDocsVehicules = () => {
        fetch(`https://sites.freeboxos.fr/Api/Vehicules/getDocsVehicule.php?page=${page}`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    setDocsVehicules(prevDocsVehicules => [...prevDocsVehicules, ...json.docsVehicule]);
                    setTotalPages(json.totalPages);
                    setHasMore(page < json.totalPages); // Met à jour l'état hasMore
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };

    // Fonction pour afficher la liste des documents des véhicules
    const keyExtractor = (item, index) => index.toString();
    const titles = ["Numero du véhicule", "Marque", "Modèle", "Immatriculation", "Nom document", "ImageVehicule"];
    const renderItem = ({ item }) => (
        <View>
            {item.idVehicule}
            {item.nom_marque}
            {item.nom_modele}
            {item.Immat}
            {item.NomDocumentVehicule}
            {item.image}
        </View>
    );

    return (
        <View style={styles.container}>
            <Header title="Liste des documents des véhicules" />
            
            <CustomFlatList
                data={docsVehicules}
                renderItem={renderItem}
                keyExtractor={keyExtractor}
                titles={titles}
                setPage={setPage}
                selectedKeys={['idVehicule', 'nom_marque', 'nom_modele', 'Immat', 'NomDocumentVehicule', 'imageVehicule']}
                hasMore={hasMore}
                navigation={navigation}
                PageName={PageName}
               
            />
            <Boutton title="Ajouter un document" onPress={() => navigation.navigate('AjoutDocumentsVehicule')} value='Ajouter' />
            <Footer />
        </View>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
 
});
export default ListeDocumentsVehicule;
