import React, { useState, useEffect } from "react";
import { View, StyleSheet, ScrollView, Alert } from "react-native";
import Header from "../../Components/Header";
import Boutton from "../../Components/Boutton";
import InputText from "../../Components/InputText";
import DropDown from "../../Components/DropDown";
import DatePicker from "../../Components/DatePicker";
import Text from "../../Components/Text";
import Footer from "../../Components/Footer";

// Fonction pour ajouter une facture
const AjoutFacture = ({ navigation }) => {
  const [montant, setMontant] = useState("");
  const [dateFacture, setDateFacture] = useState(new Date());
  const [statut, setStatut] = useState("");
  const [clients, setClients] = useState([]);
  const [idClient, setIdClient] = useState("");


 // Récupérer les clients et les véhicules lors du chargement du composant
 useEffect(() => {
  fetchAllClients();

}, []);



// Fonction pour récupérer tous les clients
const fetchAllClients = async () => {
  try {
      let allClients = [];
      let currentPage = 1;
      let morePages = true;

      while (morePages) {
          const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
          const json = await response.json();
          if (json.success) {
              allClients = [...allClients, ...json.clients.map(client => ({ label: `${client.idClient} - ${client.nom}`, value: client.idClient }))];
              currentPage++;
              morePages = currentPage <= json.totalPages;
          } else {
              Alert.alert(json.message || json.error);
              break;
          }
      }

      setClients(allClients);
  } catch (error) {
      Alert.alert('Une erreur est survenue lors de la récupération des clients');
  }
};


  // Fonction pour ajouter une facture
  const FonctionAjoutFacture = async () => {
    const formattedDateFacture = `${dateFacture.getFullYear()}-${
      "0" + (dateFacture.getMonth() + 1)
    }-${("0" + dateFacture.getDate()).slice(-2)}`;
    try {
      // Validation des champs
      if (!idClient || !montant || !dateFacture || !statut) {
        Alert.alert("Veuillez remplir correctement les champs");
        return;
      }

      // Création du formulaire
      const formData = new FormData();
      formData.append("idClient", idClient);
      formData.append("Montant", montant);
      formData.append("dateFacturation", formattedDateFacture);
      formData.append("statut", statut);
    
      // Envoi de la requête
      const response = await fetch(
        "https://sites.freeboxos.fr/Api/Administratif/insertFacture.php",
        {
          method: "POST",
          body: formData,
        }
      );
      const json = await response.json();
      if (json.success) {
        Alert.alert("Facture ajoutée avec succès");

        // Réinitialiser les champs
 
        setMontant("");
        setDateFacture(new Date());
        setStatut("");
        setIdClient("");
        navigation.navigate('Administratifs');
      } else {
        Alert.alert(json.message || json.error);
      }
    } catch (error) {
      Alert.alert("Une erreur est survenue lors de l'ajout de la facture");
    }
  };

  return (
    <ScrollView>
      <View style={styles.container}>
        <Header title="Ajout d'une facture" />

        {/* Client */}
        <DropDown
          data={clients}
          onSelect={(value) => {
            setIdClient(value);
          }}       
          label="Client"
        />

        {/* Date de la facture */}
        <View style={styles.formGroup}>
          <Text style={styles.label}>date Facture</Text>
          <DatePicker value={dateFacture} onChange={setDateFacture} />
        </View>

        <Text style={styles.label}>Montant</Text>
        <InputText
    value={`${montant} €`}
    onChangeText={text => {
        // Assurez-vous de filtrer le texte pour ne garder que les chiffres
        const numericValue = text.replace(/[^0-9.]/g, '');
        setMontant(numericValue);
    }}
/>

        <Text style={styles.label}>Statut</Text>
        <InputText
          style={styles.input}
          value={statut}
          onChangeText={setStatut}
          placeholder="Statut"
        />
        <Boutton value="Ajouter la facture" onPress={FonctionAjoutFacture} />
      </View>
      <Footer />
    </ScrollView>
  );
};
const styles = StyleSheet.create({
  container: {
    padding: 20,
    backgroundColor: "#fff",
  },
  formGroup: {
    marginBottom: 20,
  },
  label: {
    fontSize: 18,
    marginBottom: 5,
  },
});
export default AjoutFacture;
