import React, { useState, useEffect } from 'react';
import { StyleSheet, Alert, ScrollView, View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; 
import InputText from '../../Components/InputText';
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import PDFGenerator from '../../Components/PDFGenerator';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

const FactureDetails = ({ route }) => {
    const selectedItem = route?.params?.selectedItem || {}; 
    const [idClient, setIdClient] = useState(selectedItem.idClient);
    const [editedMontant, setEditedMontant] = useState(selectedItem.Montant);
    const [editedDate, setEditedDate] = useState(selectedItem.DateFacturation);
    const [editedStatut, setEditedStatut] = useState(selectedItem.Statut);
    const [idFacture, setIdFacture] = useState(selectedItem.idFacture); 
    const navigation = useNavigation(); 
    const [clients, setClients] = useState([]);
    const [nomClient, setNomClient] = useState('');
    const [prenomClient, setPrenomClient] = useState('');
    const [genreClient, setGenreClient] = useState('');
  

    useEffect(() => {
        fetchAllClients();
    }, []);
  
     // Fonction pour récupérer les clients
     const fetchAllClients = async () => {
        try {
            let allClients = [];
            let currentPage = 1;
            let morePages = true;

            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allClients = [...allClients, ...json.clients.map(client => ({
                        label: `${client.idClient}  - ${client.Genre} ${client.nom}`,
                        value: client.idClient,
                        genreclient: client.Genre,
                        nom: client.nom,
                        prenom: client.prenom
                    }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    console.error(json.message || json.error);
                    break;
                }
            }

            setClients(allClients);

            // Si un client est déjà sélectionné, récupérez ses détails
            const selectedClientData = allClients.find(client => client.value === idClient);
            if (selectedClientData) {
                setNomClient(selectedClientData.nom);
                setPrenomClient(selectedClientData.prenom);
                setGenreClient(selectedClientData.genreclient);
            }

        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des clients');
        }
    };
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idClient', selectedItem.idClient);
            formData.append('Montant', editedMontant);
            formData.append('DateFacturation', editedDate);
            formData.append('Statut', editedStatut);
            formData.append('idFacture', selectedItem.idFacture);

            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/updateFacture.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Administratifs');
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idFacture', selectedItem.idFacture);

            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/supprFacture.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                navigation.navigate('Administratifs'); 
                Alert.alert('Succès', data.message);
            } else {
                const errorData = await response.json(); 
                if (errorData.error.includes('Impossible de supprimer la Facture car est utilisé ')) {
                    Alert.alert('Erreur', errorData.error);
                } else {
                    Alert.alert('Erreur lors de la suppression de l\'élément:', errorData.error);
                }
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };

    return (
        <ScrollView>
            <Header title="Détails de la facture" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID de la Facture: {selectedItem.idFacture}</Text>
            <Text>Supplements:</Text>

            <DropDown   
                data={clients}
                onSelect={value => setIdClient(value)}
                placeholder="Sélectionnez un client"
                selectedValue={idClient}
            />

            <InputText
                value={editedStatut}
                onChangeText={setEditedStatut}
            />
         <InputText
    value={`${editedMontant} €`}
    onChangeText={text => {
        // Assurez-vous de filtrer le texte pour ne garder que les chiffres
        const numericValue = text.replace(/[^0-9.]/g, '');
        setEditedMontant(numericValue);
    }}
/>
            <Text>Date:</Text>
            <InputText
                value={editedDate}
                onChangeText={setEditedDate}
            />

            <View style={styles.dataContainer}>
                <PDFGenerator
                    documentData={{
                        idFacture: idFacture,
                        Client: `${genreClient} ${nomClient}  ${prenomClient} `,  
                        Montant: editedMontant + ' €', // Ajout du symbole euro ici
                        DateFacturation: editedDate,
                        Statut: editedStatut
                    }}
                    documentType="Facture"
                />
                <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
                <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
});

export default FactureDetails;
