//module réinitialisation du mot de passe
import React, { useState } from 'react';
import { Alert, TouchableOpacity, StyleSheet, View, Text} from 'react-native';
import { emailValidator, passwordValidator } from '../core/utils';
import Header from '../Components/Header';
import InputText from '../Components/InputText';
import Boutton from '../Components/Boutton';


// réinitialisation du mot de passe
export default function ForgotPasswordScreen({ navigation }) {
    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');
    const [password2, setPassword2] = useState('');

    const fonctionEnvoi = () => {
        const emailError = emailValidator(email);
        const passwordError = passwordValidator(password);

        //vérfication des erreurs
        if (emailError || passwordError) {
            Alert.alert('Erreur', 'Email ou mot de passe incorrect');
            return;
        }

        if (password !== password2) {   
            Alert.alert('Erreur', 'Les mots de passe ne correspondent pas');
            return;
        }
        //envoi des données à l'API
        const formData = new FormData();
        formData.append("email", email);
        formData.append("password", password);

        fetch('https://sites.freeboxos.fr/Api/updateUser.php', {
            method: 'POST',
            body: formData,
            headers: {
                "Content-Type": "multipart/form-data"
            },
        })
        .then(response => response.json())
        .then(json => {
            if (json.success) {
                navigation.navigate('LoginScreen');
            } else {
                Alert.alert('Erreur', 'L\'e-mail saisi n\'existe pas');
            }
        })
        .catch(error => {
            console.error(error);
            Alert.alert('Erreur', 'Une erreur s\'est produite. Veuillez réessayer.');
        });
    };

    return (
        <View style={styles.container}>
            <Header title="Réinitialiser son mot de passe" />
          
                <View style={styles.formContainer}>
                    <Text>Email</Text>
                    <InputText
                        style={styles.input}
                        value={email}
                        onChangeText={text => setEmail(text)}
                        placeholder="Saisir votre adresse mail"
                    />
                    <Text>Mot de passe</Text>
                    <InputText
                        placeholder="Saisir votre mot de passe"
                        style={styles.input}
                        value={password}
                        onChangeText={text => setPassword(text)}
                        secureTextEntry
                    />
                    <InputText
                        placeholder="Resaisir votre mot de passe"
                        style={styles.input}
                        value={password2}
                        onChangeText={text => setPassword2(text)}
                        secureTextEntry
                    />
                    <Boutton onPress={fonctionEnvoi} value="Envoyer" />
                    <TouchableOpacity onPress={() => navigation.navigate('HomeScreen')}>
                        <Text >Retourner à l'accueil</Text>
                    </TouchableOpacity>
                </View>
        
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
    },
    formContainer: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        paddingHorizontal: 20,
    },
  
   
});
