import React, { useState } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; 
import Text from '../../Components/Text';
import Header from '../../Components/Header';
import InputText from '../../Components/InputText';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'un genre
const GenreDetails = ({ route }) => {
    const selectedItem = route?.params?.selectedItem || {}; 
    const [editedGenre, setEditedGenre] = useState(selectedItem.Genre);
    const navigation = useNavigation(); 


// Fonction pour modifier un élément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idGenre', selectedItem.idGenre);
            formData.append('Genre', editedGenre);
            const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/updateGenre.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
              
                Alert.alert('Succès', data.message);
                navigation.navigate('Listes'); 
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un élément
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idGenre', selectedItem.idGenre);
    
            const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/supprGenre.php`, {
                method: 'POST',
                body: formData,
            });
    
            if (response.ok) {
                const data = await response.json();
                navigation.navigate('Listes'); 
                Alert.alert('Succès', data.message);
                
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };

    return (
        <View>
            <Header title="Détails civilité" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du genre: {selectedItem.idGenre}</Text>
         
   <InputText placeholder="Nouveau genre"
                    value={editedGenre}
                    onChangeText={setEditedGenre}
                />
     <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
            
        </View>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
   
   
});

export default GenreDetails;
