import React, { useState, useEffect } from 'react';
import { View, StyleSheet, ScrollView, Alert } from 'react-native';
import InputText from '../../Components/InputText';
import Boutton from '../../Components/Boutton';
import Header from '../../Components/Header';
import DropDown from '../../Components/DropDown';
import DatePicker from '../../Components/DatePicker';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour ajouter une infraction
const AjoutInfraction = ({ navigation }) => {
    const [numAmmende, setNumAmmende] = useState('');
    const [dateInfraction, setDateInfraction] = useState(new Date());
    const [clients, setClients] = useState([]);
    const [selectedClient, setSelectedClient] = useState('');
    const [vehicules, setVehicules] = useState([]);
    const [selectedVehicule, setSelectedVehicule] = useState('');
    const [montant, setMontant] = useState('');

   
    
    useEffect(() => {
        fetchAllClients();
        fetchAllVehicules();
    }, []);
    
    // Fonction pour récupérer tous les clients
    const fetchAllClients = async () => {
        try {
            let allClients = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allClients = [...allClients, ...json.clients.map(client => ({ label: `${client.idClient} - ${client.nom}`, value: client.idClient }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    Alert.alert(json.message || json.error);
                    break;
                }
            }
    
            setClients(allClients);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des clients.');
        }
    };
      // Fonction pour récupérer les véhicules
      const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    Alert.alert(json.message || json.error);
                    break;
                }
            }
    
            setVehicules(allVehicules);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des véhicules.');
        }
    };

    // Fonction pour ajouter une infraction
    const FonctionAjoutInfraction = async () => {
        try {
            if (!numAmmende || !dateInfraction || !selectedClient || !selectedVehicule || !montant) {
                Alert.alert('Veuillez remplir correctement les champs');
                return;
            }
            const formattedDateInfraction = `${dateInfraction.getFullYear()}-${('0' + (dateInfraction.getMonth() + 1)).slice(-2)}-${('0' + dateInfraction.getDate()).slice(-2)}`;
            const formData = new FormData();
            formData.append("NumeroAmmende", numAmmende);
            formData.append("Date", formattedDateInfraction);
            formData.append("idClient", selectedClient);
            formData.append("idVehicule", selectedVehicule);
            formData.append("Montant", montant);
            const response = await fetch('https://sites.freeboxos.fr/Api/Administratif/insertInfraction.php', {
                method: 'POST',
                body: formData,
            });

            const json = await response.json();
            if (json.success) {
                Alert.alert('Infraction ajoutée avec succès');
                setNumAmmende('');
                setDateInfraction(new Date());
                setSelectedClient('');
                setSelectedVehicule('');
                setMontant('');
                navigation.navigate('Administratifs');
            } else {
                Alert.alert(json.message || json.error);
            }
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de l\'ajout de l\'infraction.');
        }
    };

    return (
        <ScrollView contentContainerStyle={styles.container}>
            <Header title="Ajout d'une infraction" />
            <View style={styles.formGroup}>
                <Text style={styles.label}>Numéro Ammende</Text>
                <InputText value={numAmmende} onChangeText={setNumAmmende} />
            </View>
            <View style={styles.formGroup}>
                <Text style={styles.label}>Date de l'infraction</Text>
                <DatePicker value={dateInfraction} onChange={setDateInfraction} />
            </View>
            <DropDown
                data={clients}
                onSelect={value => setSelectedClient(value)}
                placeholder="Sélectionnez un client"
            
            />
            <DropDown
                data={vehicules}
                onSelect={value => setSelectedVehicule(value)}
                placeholder="Sélectionnez un véhicule"
             
            />
            <View style={styles.formGroup}>
                <Text style={styles.label}>Montant:</Text>
                <InputText
    value={`${montant} €`}
    onChangeText={text => {
        // Assurez-vous de filtrer le texte pour ne garder que les chiffres
        const numericValue = text.replace(/[^0-9.]/g, '');
        setMontant(numericValue);
    }}
/>
            </View>
            <Boutton value="Ajouter l'infraction" onPress={FonctionAjoutInfraction} />
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    container: {
        padding: 20,
        backgroundColor: '#fff',
    },
    formGroup: {
        marginBottom: 20,
    },
    label: {
        fontSize: 18,
        marginBottom: 5,
    },
});

export default AjoutInfraction;
