import React, { useState, useEffect } from 'react';
import { StyleSheet, Alert,  ScrollView, View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; 
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import InputText from '../../Components/InputText';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'une infraction
const InfractionDetails = ({ route }) => {
    const { selectedItem } = route.params;
    const [idInfraction, setIdInfraction] = useState(selectedItem.idInfraction);
    const [selectedVehicule, setSelectedVehicule] = useState(selectedItem.idVehicule); 
    const [montantInfraction, setMontantInfraction] = useState(selectedItem.Montant); 
    const [selectedClient, setSelectedClient] = useState(selectedItem.idClient);
    const [dateInfraction, setDateInfraction] = useState(selectedItem.Date);
    const [numeroAmmende, setNumeroAmmende] = useState(selectedItem.NumeroAmmende); 
    const [vehicules, setVehicules] = useState([]);
    const [clients, setClients] = useState([]);
    const navigation = useNavigation();

    useEffect(() => {
        fetchAllVehicules();
        fetchAllClients();
    }, []);


 // Fonction pour récupérer tous les clients
 const fetchAllClients = async () => {
    try {
        let allClients = [];
        let currentPage = 1;
        let morePages = true;

        while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
                allClients = [...allClients, ...json.clients.map(client => ({ label: `${client.idClient}  - ${client.Genre} ${client.nom}`, value: client.idClient }))];
                currentPage++;
                morePages = currentPage <= json.totalPages;
            } else {
                console.error(json.message || json.error);
                break;
            }
        }

        setClients(allClients);
    } catch (error) {
        Alert.alert('Une erreur est survenue lors de la récupération des clients');
    }
};
 
    // Fonction pour récupérer les véhicules
    const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;

            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    console.error(json.message || json.error);
                    break;
                }
            }

            setVehicules(allVehicules);
        } catch (error) {
           Alert.alert('Une erreur est survenue lors de la récupération des véhicules');
        }
    };

// Fonction pour modifier un élément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idInfraction', idInfraction);
            formData.append('idVehicule', selectedVehicule);
            formData.append('idClient', selectedClient);
            formData.append('Date', dateInfraction);
            formData.append('Montant', montantInfraction);
           formData.append('NumeroAmmende', numeroAmmende);
           
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/updateInfraction.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Administratifs');
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };


    // Fonction pour supprimer un élément
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idInfraction', idInfraction);
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/supprInfraction.php`, {
                method: 'POST',
                body: formData,
            });
    
            if (response.ok) {
                const data = await response.json();
                navigation.navigate('Administratifs');
                Alert.alert('Succès', data.message);
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };

    return (
        <ScrollView>
            <Header title="Détails de l'infraction" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID Infraction : {idInfraction}</Text>
      
            <DropDown
                data={vehicules}
                onSelect={value => setSelectedVehicule(value)}
                placeholder="Sélectionnez un véhicule"
                selectedValue={selectedVehicule}
            />
            <DropDown   
                data={clients}
                onSelect={value => setSelectedClient(value)}
                placeholder="Sélectionnez un client"
                selectedValue={selectedClient}
            />
            <Text>date de l'infraction : </Text>
            <InputText
                value={dateInfraction}
                onChangeText={setDateInfraction}
            />
         
            <Text>Montant amende: </Text>
            <InputText
    value={`${montantInfraction} €`}
    onChangeText={text => {
        // Assurez-vous de filtrer le texte pour ne garder que les chiffres
        const numericValue = text.replace(/[^0-9.]/g, '');
        setMontantInfraction(numericValue);
    }}
/>
            <Text>Numéro amende: </Text>
            <InputText
                value={numeroAmmende}
                onChangeText={setNumeroAmmende}
                
            />
           <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
   
  
});

export default InfractionDetails;
