import React, { useEffect, useState } from 'react';
import { View,  StyleSheet, Alert} from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList'; 
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';


const ListeInfractions = ({navigation}) => {
    const [infractions, setInfractions]= useState([]);
    const [page, setPage] = useState(1);
    const [hasMore, setHasMore] = useState(true);
   const [totalPages, setTotalPages] = useState(0);
   const PageName = ['InfractionDetails'];
// Récupérer les infractions lors du chargement du composant
    useEffect(() => {
        fetchInfractions();
    }, [page]);

       // Fonction pour récupérer les infractions 
        const fetchInfractions = () => {
        fetch(`https://sites.freeboxos.fr/Api/Administratif/getInfractions.php?page=${page}`)
        .then((response) => response.json())
        .then((json) => {
            if (json.success) {
                setInfractions(prevInfractions=> [...prevInfractions, ...json.infractions]);
                setTotalPages(json.totalPages);
                setHasMore(page < json.totalPages);
               
            } else {
                Alert.alert(json.message || json.error);
            }
        })
        .catch((error) => console.error(error))
    };


    const keyExtractor = (item, index) => index.toString();
    const titles = ["Numero de l'infractions", "Numéro de l'amende ", "Date ","Nom du client", "Numéro du véhicule","Marque", "Modèle", "Immatriculation ",  "Montant"];

    const renderItem = ({ item }) => (
        <View>
       
       {item.idInfraction}
        {item.NumeroAmmende}
        {item.Date}
        {item.nom_client}
        {item.idVehicule}
        {item.nom_marque}
        {item.nom_modele}
        {item.Immat}
        {item.Montant}
        </View>
    );


    return (
        <View style={styles.container}>
            <Header title="Liste des infractions " />
           
                <CustomFlatList
                    data={infractions}
                    renderItem={renderItem}
                    keyExtractor={keyExtractor}
                    titles={titles}
                    setPage={setPage}
                    selectedKeys={['idInfraction', 'NumeroAmmende', 'Date','nom_client','idVehicule', 'nom_marque', 'nom_modele', 'Immat', 'Montant']}
                    hasMore={hasMore} 
                    navigation={navigation}
                    PageName={PageName} 
                />
                 <Boutton title="Ajouter une infraction" onPress={() => navigation.navigate('AjoutInfraction')} value='Ajouter' />
                <Footer />
        </View>
    );
};

 
const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },

});

            export default ListeInfractions;