//page de connexion
import React, { useState } from 'react';
import { Alert, TouchableOpacity, StyleSheet, View, Text, ScrollView  } from 'react-native';
import Header from '../Components/Header';
import InputText from '../Components/InputText';
import Boutton from '../Components/Boutton';
import { emailValidator, passwordValidator } from '../core/utils';
import BackgroundImage from '../Components/BackgroundImage';
import { useDispatch } from 'react-redux';
import { setUser } from '../actions/userActions';

// Composant pour la connexion
export default function LoginScreen({ navigation }) {
    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');
    const dispatch = useDispatch(); // Déclaration de dispatch
    // Fonction pour la connexion si les champs sont valides au clique sur le bouton
    const onLoginPressed = () => {
        const emailError = emailValidator(email);
        const passwordError = passwordValidator(password);

        if (emailError || passwordError) {
            Alert.alert("Invalid email or password");
            return;
        }

        // Formulaire de connexion et envoi des données à l'API
        const formData = new FormData();
        formData.append("password", password);
        formData.append("email", email);

        fetch('https://sites.freeboxos.fr/Api/getUser.php', {
            method: 'POST',
            body: formData,
            headers: {
                "Content-Type": "multipart/form-data"
            },
        })
        .then(response => response.json())
        .then(json => {
            console.log("JSON Response:", json);

            if (json.success) {
                setEmail("");
                setPassword("");
               
                dispatch(setUser(json.user)); 
                navigation.navigate('Dashboard');
              
            } else {
                // Si l'authentification a échoué, affiche une alerte
                Alert.alert(
                    'Erreur',
                    'Le pseudo ou le mot de passe est incorrect',
                    [{ text: 'OK', onPress: () => console.log('OK Pressed') }],
                    { cancelable: false }
                );
            }
        })
        .catch(error => {
            console.error(error);
            Alert.alert(
                'Erreur',
                'Une erreur s\'est produite. Veuillez réessayer.',
                [{ text: 'OK', onPress: () => console.log('OK Pressed') }],
                { cancelable: false }
            );
        });
    };

    return (
      
        <ScrollView contentContainerStyle={{ flexGrow: 1 }}>
            <Header title="Connexion" />
            <BackgroundImage source={require('../assets/fascars.png')} style={styles.backgroundImage}>
            <View style={styles.formContainer}>
                    <Text>Email</Text>
                    <InputText
                        style={styles.input}
                        value={email}
                        onChangeText={text => setEmail(text)}
                        placeholder="Saisir votre adresse mail"
                    />
                    <Text>Mot de passe</Text>
                    <InputText
                        label="password"
                        returnKeyType="done"
                        placeholder="Saisir votre mot de passe"
                        style={styles.input}
                        value={password}
                        onChangeText={text => setPassword(text)}
                        secureTextEntry
                    />
                    <Boutton onPress={onLoginPressed} value="Connexion" />
                    <View style={styles.row}>
                    
                   
                        <TouchableOpacity onPress={() => navigation.navigate('ForgotPasswordScreen')}>
                            <Text>Mot de passe oublié</Text>
                        </TouchableOpacity>
                    </View>
                </View>
                </BackgroundImage>
        </ScrollView>
       
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
        justifyContent: 'center',
    },
    formContainer: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        paddingHorizontal: 20,
    },
  
    row: {
        flexDirection: 'row',
        marginTop: 10,
        justifyContent: 'space-between',
    },
  


 
});