import React, { useState } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; // Importer useNavigation
import InputText from '../../Components/InputText';
import Text from '../../Components/Text';
import Header from '../../Components/Header';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'une marque
const MarqueDetails = ({ route }) => {
    const selectedItem = route?.params?.selectedItem || {}; 
    const [editedMarque, setEditedMarque] = useState(selectedItem.nom);
    const navigation = useNavigation(); // Utiliser useNavigation pour obtenir l'objet de navigation


//
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idMarque', selectedItem.idMarque);
            formData.append('nom', editedMarque);
      
            const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/updateMarque.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Listes'); 
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer une marque
   const handleDeleteItem = async () => {
    try {
        const formData = new FormData();
        formData.append('idMarque', selectedItem.idMarque);

        const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/supprMarque.php`, {
            method: 'POST',
            body: formData,
        });

        if (response.ok) {
            const data = await response.json();
            navigation.navigate('Listes'); 
            Alert.alert('Succès', data.message);
        } else {
            const errorData = await response.json(); 
            if (errorData.error.includes('Impossible de supprimer la marque')) {
                Alert.alert('Erreur', errorData.error);
            } else {
                // Sinon, afficher l'erreur standard
                Alert.alert('Erreur lors de la suppression de l\'élément:', errorData.error);
            }
        }
    } catch (error) {
        Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
    }
};
    return (
        <View>
            <Header title="Détails de la marque" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID de la Marque: {selectedItem.idMarque}</Text>
            <InputText
                value={editedMarque}
                onChangeText={setEditedMarque}
            />
              <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </View>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
   
   
});

export default MarqueDetails;
