import React, { useState, useEffect } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import { useNavigation } from '@react-navigation/native';
import Header from "../../Components/Header";
import Boutton from "../../Components/Boutton";
import InputText from "../../Components/InputText";
import DropDown from "../../Components/DropDown";
import Footer from '../../Components/Footer';

const AjoutModele = () => {
    const [nouveauModele, setNouveauModele] = useState('');
    const [selectedMarque, setSelectedMarque] = useState(null);
    const [marques, setMarques] = useState([]); 
    const navigation = useNavigation();
 
    useEffect(() => {
        fetchMarques();
    }, []);

    const fetchMarques = () => {
        fetch(`https://sites.freeboxos.fr/Api/Listes/getMarques.php`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    setMarques(json.marques.map(marque => ({ label: marque.nom, value: marque.idMarque })));
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };

    // Fonction pour ajouter un nouveau modèle
    const ajouterNouveauModele = () => {
        if (!selectedMarque) {
            Alert.alert('Erreur', 'Veuillez sélectionner une marque.');
            return;
        }

        if (nouveauModele.trim() === '') {
            Alert.alert('Erreur', 'Veuillez entrer le nom du nouveau modèle.');
            return;
        }

        const formData = new FormData();
        formData.append("nouveauModele", nouveauModele);
        formData.append("idMarque", selectedMarque);

        fetch(`https://sites.freeboxos.fr/Api/Listes/insertModele.php`, {
            method: 'POST',
            body: formData,
        })
        .then((response) => response.json())
        .then((json) => {
            if (json.success) {
                Alert.alert('Nouveau modèle ajouté avec succès dans la base de données.');
                setNouveauModele('');
                setSelectedMarque(null);
                navigation.navigate('Listes'); 
            } else {
                Alert.alert(json.message || json.error);
            }
        })
        .catch((error) => console.error(error));
    };

    return (
        <View style={styles.container}>
            <Header title="Ajout d'un nouveau modèle" />
            <DropDown
    data={marques} onSelect={value => {setSelectedMarque(value);}}
    placeholder="Sélectionnez une marque"
/>

            <InputText
                placeholder="Nouveau modèle"
                value={nouveauModele}
                onChangeText={setNouveauModele}
            />
            <Boutton onPress={ajouterNouveauModele} value="Ajouter" />
            <Footer />
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
});

export default AjoutModele;