import React, { useEffect, useState } from 'react';
import { View,StyleSheet, Alert } from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

const ListeModele = ({ navigation }) => {
    const [modeles, setModeles] = useState([]);
    const PageName = ['ModeleDetails'];

    useEffect(() => {
       
        navigation.addListener('focus', () => {
            fetchModeles();
        });
    }, [navigation]);


    // Fonction pour récupérer les modeles
    const fetchModeles = () => {
        fetch(`https://sites.freeboxos.fr/Api/Listes/getAllModeles.php`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    setModeles(json.modeles);
                   
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };
    
    const keyExtractor = (item, index) => index.toString();
    const titles = ["Modele"];

    const renderItem = ({ item }) => (
        <View>
            {item.nomModele}
            {item.nomMarque}
        </View>
    );

    return (
        <View style={styles.container}>
            <Header title="Liste des modeles" />

            <CustomFlatList
                data={modeles}
                renderItem={renderItem}
                keyExtractor={keyExtractor}
                titles={titles}
                selectedKeys={['nom_Modele','nom_Marque']}
                navigation={navigation}
                PageName={PageName} // Passer le nom de la page en tant que prop    
            />
              <Boutton onPress={() => navigation.navigate('AjoutModele')} value="ajouter" />
            <Footer />
        </View>
    );
};
const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
  
});


export default ListeModele;
