import React, { useEffect, useState } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';
import Boutton from '../../Components/Boutton';                                                                             
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';


// Fonction pour afficher la liste des photos des véhicules
const ListePhotosVehicule = ({ navigation }) => {
    const [photosVehicule, setPhotosVehicule] = useState([]);
    const [page, setPage] = useState(1);
    const [totalPages, setTotalPages] = useState(0);
    const [hasMore, setHasMore] = useState(true);
 
    const PageName = ['PhotosVehiculeDetails'];

     useEffect(() => {
        fetchPhotosVehicule();
    }, [page]);

    // Fonction pour récupérer les documents des véhicules
    const fetchPhotosVehicule = () => {
        fetch(`https://sites.freeboxos.fr/Api/Vehicules/getPhotosVehicule.php?page=${page}`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    setPhotosVehicule(prevPhotosVehicule => [...prevPhotosVehicule, ...json.photosVehicule]);
                    setTotalPages(json.totalPages);
                    setHasMore(page < json.totalPages);
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };

    // Fonction pour afficher la liste des photos des véhicules
    const keyExtractor = (item, index) => index.toString();
    const titles = ["Numero du véhicule", "Marque", "Modèle", "Immatriculation", "Nom document", "ImageVehicule"];
    const renderItem = ({ item }) => (
        <View>
            <Text>{item.idVehicule}</Text>
            <Text>{item.nom_marque}</Text>
            <Text>{item.nom_modele}</Text>
            <Text>{item.Immat}</Text>
            <Text>{item.nomPhoto}</Text>
            <Text>{item.image}</Text>
        </View>
    );



    return (
        <View style={styles.container}>
            <Header title="Liste des photos des véhicules" />

      
            <CustomFlatList
                data={photosVehicule}
                renderItem={renderItem}
                keyExtractor={keyExtractor}
                titles={titles}
                setPage={setPage}
                selectedKeys={['idVehicule', 'nom_marque', 'nom_modele', 'Immat', 'nomPhoto', 'imageVehicule']}
                hasMore={hasMore}
                PageName={PageName} // Passer le nom de la page en tant que prop
                navigation={navigation}
            />
                  <Boutton onPress={() => navigation.navigate('AjoutPhotosVehicule')} value="ajouter" />
            <Footer />
        </View>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
});

export default ListePhotosVehicule;
