import React, { useState } from 'react';
import { View, StyleSheet, Alert, ScrollView } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native';
import InputText from '../../Components/InputText';
import SelectedImageServer from '../../Components/SelectedImageServeur';
import Header from '../../Components/Header';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'une photo de véhicule
const PhotosVehiculeDetails = ({ route }) => {
    const selectedItem = route?.params?.selectedItem || {};
    const [editedPhoto, setEditedPhoto] = useState(selectedItem.nomPhoto);
    const navigation = useNavigation();
    const [selectedImage, setSelectedImage] = useState(selectedItem.imageVehicule);
    const [selectedidVehicule, setSelectedidVehicule] = useState(selectedItem.idVehicule);
  
// Fonction pour modifier une photo de véhicule
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idPhoto', selectedItem.idPhoto);
            formData.append('nomPhoto', editedPhoto);   
                                         
            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/updatePhotosVehicule.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Listes'); 
                setEditedPhoto('');
                setSelectedImage(null);
                setSelectedidVehicule('');
                setEditedPhoto('');

            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer une photo de véhicule
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idPhoto', selectedItem.idPhoto);
    
            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/supprPhotosVehicule.php`, {
                method: 'POST',
                body: formData,
            });
    
            if (response.ok) {
                const data = await response.json();
              
                Alert.alert('Succès', data.message);
                navigation.navigate('Listes'); 
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };
    

    return (
        <ScrollView>
            <View>
                <Header title="Détails de la photo du véhicule" />
                <Text style={styles.title}>   {selectedItem.idVehicule}  
                {selectedItem.nom_marque} 
                {selectedItem.nom_modele}</Text>
                <Text>ID de la photo: {selectedItem.idPhoto}
             
        </Text>
                <InputText
                    value={editedPhoto}
                    onChangeText={setEditedPhoto}
                />
                <SelectedImageServer uri={selectedImage} />
                    <View style={styles.dataContainer}>
                <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
                <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
                </View>
            </View>
            <Footer />
        </ScrollView>
    );
};    

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
   
});

export default PhotosVehiculeDetails;
