//page d'inscription
import React, { useState } from 'react';
import { View, StyleSheet, TouchableOpacity, Alert, ScrollView, Text } from 'react-native';
import Header from '../Components/Header';
import { emailValidator, passwordValidator,  nameValidator, firstnameValidator } from '../core/utils';
import InputText from '../Components/InputText';
import Boutton from '../Components/Boutton';
import BackgroundImage from '../Components/BackgroundImage';
import Footer from '../Components/Footer';

// Composant pour la page d'inscription
export default function RegisterScreen({ navigation }) {

  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [password2, setPassword2] = useState('');
  const [name, setName] = useState('');

  // Fonction pour l'inscription si les champs sont valides à la pression du bouton
  const FonctionIncription = async () => {
    try {
     
      const emailError = emailValidator(email);
      const passwordError = passwordValidator(password);
      const nameError = nameValidator(name);

      // Vérification des champs du mot de passe
      if (password !== password2) {
        Alert.alert('Les mots de passe ne correspondent pas');
        return;
      }
      // Vérification des champs si vides
      if (emailError || passwordError || nameError ) {
        Alert.alert('Veuillez remplir correctement les champs');
        return;
      }
      // Formulaire d'inscription
      const formData = new FormData();
      formData.append("email", email);
      formData.append("password", password);
      formData.append("name", name);

      // Envoi à l'API des données au serveur
      const response = await fetch('https://sites.freeboxos.fr/Api/insertUser.php', {
        method: 'POST',
        body: formData,
        headers: {
          "Content-Type": "multipart/form-data"
        },
      });

      const json = await response.json();
      // Si l'inscription est réussie
      if (json.success) {
    
        setEmail('');
        setPassword('');
        setName('');
        setPassword2('');

        navigation.navigate('Dashboard');
      } else {
        Alert.alert('L\'e-mail saisi existe déjà. Veuillez saisir une autre adresse mail ou récupérer votre compte');
      }
    } catch (error) {
      console.error(error);
    }
  };

  return (
    <ScrollView contentContainerStyle={styles.scrollContainer}>
      <Header title="Inscription" />
      <BackgroundImage source={require('../assets/fascars.png')}>
        <View style={styles.formContainer}>
          <Text style={styles.text}>Email</Text>
          <InputText
            style={styles.input}
            value={email}
            onChangeText={(text) => setEmail(text)}
            placeholder="Veuillez entrer une adresse mail"
          />

          <Text style={styles.text}>Mot de passe</Text>
          <InputText
            label="password"
            returnKeyType="done"
            style={styles.input}
            value={password}
            onChangeText={text => setPassword(text)}
            placeholder="Saisir un mot de passe"
            secureTextEntry
          />

          <InputText
            label="password2"
            returnKeyType="done"
            style={styles.input}
            value={password2}
            onChangeText={text => setPassword2(text)}
            placeholder="Resaisir le mot de passe"
            secureTextEntry
          />

          <Text style={styles.text}>Nom</Text>
          <InputText
            style={styles.input}
            value={name}
            placeholder="Entrer un nom"
            onChangeText={(text) => setName(text)}
          />

          <Boutton onPress={FonctionIncription} value="Ajouter un nouvel utilisateur" />
  
        </View>
      </BackgroundImage>
      <Footer />
    </ScrollView>
  );
};

const styles = StyleSheet.create({
  scrollContainer: {
    flexGrow: 1,
   
  },
  container: {
    flex: 1,
    padding: 20,
    justifyContent: 'center',
  },
  formContainer: {  
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    paddingHorizontal: 20,
  },
  row: {
    flexDirection: 'row',
    marginBottom: 4,
  },
  input: {
    height: 40,
    borderColor: 'gray',
    borderWidth: 1,
    margin: 10,
    width: '100%',
  },
  text: {
    fontSize: 16,
    marginBottom: 10,
  }
});

