import React, { useState, useEffect } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

// Fonction pour afficher la liste des suppléments
const ListeSupplements = ({ navigation }) => {
    const [charges, setCharges] = useState([]);
    const PageName = ['SupplementsDetails'];

    useEffect(() => {
        fetchListeCharges();
    }, []);

  // Fonction pour récupérer la liste des suppléments
    const fetchListeCharges = () => {
        fetch(`https://sites.freeboxos.fr/Api/Listes/getSuplements.php`)
        .then((response) => response.json())
        .then((json) => {
            if (json.success) {
                setCharges(json.charges);  
            } else {
                Alert.alert(json.message || json.error);
            }
        })
        .catch((error) => console.error(error));
    };
    
  

    const keyExtractor = (item, index) => index.toString();
    const titles = ["Numéro du suppléments", "Suppléments","Frais", "Description"];
    const renderItem = ({ item }) => (
        <View>
            {item.idSupplements}
            {item.nom}
            {item.frais}
            {item.description}
          
        </View>
    );
    
    return (
        <View style={styles.container}>
            <Header title="Liste des supplements " />
            <CustomFlatList
                data={charges}
                renderItem={renderItem}
                keyExtractor={keyExtractor}
                titles={titles}
                selectedKeys={['idSupplements','nom',  'frais', 'description' ]} 
                navigation={navigation}
                PageName={PageName}
            />
            
            <Boutton onPress={() => navigation.navigate('AjoutSupplements')} value="ajouter" />
            <Footer />
        </View>
    );
};
    
const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
});

export default ListeSupplements;
