import React, { useEffect, useState } from 'react';
import { View, StyleSheet, Alert, ScrollView } from 'react-native'; 
import Header from '../../Components/Header';
import Boutton from '../../Components/Boutton';
import InputText from '../../Components/InputText';
import { immatValidator, motorisationValidator, couleurValidator, kilometrageValidator, placesValidator, vitesseValidator, tarifJourValidator, descriptionValidator } from '../../core/utils';
import DropDown from '../../Components/DropDown';
import DatePicker from '../../Components/DatePicker';
import ProgressBarSlider from '../../Components/ProgressBarSlider';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour ajouter un nouveau véhicule
const AjoutVehicule = ({ navigation }) => {
    const [marques, setMarques] = useState([]);
    const [modeles, setModeles] = useState([]);
    const [typesVehicule, setTypesVehicule] = useState([]);
    const [selectedMarque, setSelectedMarque] = useState('');
    const [selectedModele, setSelectedModele] = useState('');
    const [selectedTypeVehicule, setSelectedTypeVehicule] = useState('');
    const [immat, setImmat] = useState('');
    const [annee, setAnnee] = useState(new Date());
    const [motorisation, setMotorisation] = useState('');
    const [couleur, setCouleur] = useState('');
    const [kilometrage, setKilometrage] = useState('');
    const [places, setPlaces] = useState('');
    const [Boitevitesse, setBoitevitesse] = useState('');
    const [tarifJour, setTarifJour] = useState('');
    const [statuts, setStatuts] = useState([]);
    const [selectedStatut, setSelectedStatut] = useState('');
    const [description, setDescription] = useState('');
    const [niveauCarburant, setNiveauCarburant] = useState(''); 
   
   
    useEffect(() => {
        fetchMarques();
        fetchStatuts();
        fetchTypeVehicule();

        if (selectedMarque) {
            fetchModeles(selectedMarque);
        }
    }, [selectedMarque]);


//  Fonction pour récupérer les marques
  const fetchMarques = () => {
        fetch('https://sites.freeboxos.fr/Api/Listes/getMarques.php')
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    setMarques(json.marques.map(marque => ({ label: `${marque.idMarque} - ${marque.nom}`, value: marque.idMarque })));
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };

      // Fonction pour récupérer les statuts
       const fetchStatuts = () => {
        fetch('https://sites.freeboxos.fr/Api/Listes/getStatuts.php')
            .then((response) => response.json())
            .then((json) => { 
                if (json.success){ 
                    setStatuts(json.statuts.map(statut => ({ label: `${statut.idStatut} - ${statut.Statut}`, value: statut.idStatut })));
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };

    // Fonction pour récupérer les types de véhicules
          const fetchTypeVehicule = () => {  
        fetch('https://sites.freeboxos.fr/Api/Listes/getTypesVehicules.php')
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    setTypesVehicule(json.typesVehicules.map(typesVehicule => ({ label: `${typesVehicule.idTypeVehicule} - ${typesVehicule.nomType}`, value: typesVehicule.idTypeVehicule })));
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    
    };
 

  // Fonction pour récupérer les modèles en fonction de l'identifiant de la marque sélectionnée
const fetchModeles = (idMarque) => {
    // Vérifier si l'identifiant de la marque est défini et non vide
    if (!idMarque || idMarque.length === 0) {
        // Si la marque n'est pas sélectionnée, ne rien faire
        return;
    }

    // Si une marque est sélectionnée, récupérer les modèles
    fetch(`https://sites.freeboxos.fr/Api/Listes/getModeles.php?idMarque=${idMarque}`)
        .then((response) => response.json())
        .then((json) => {
            if (json.success) {
                const mappedModeles = json.modeles.map(modele => ({ label: modele.nom, value: modele.idModele }));
                setModeles(mappedModeles);
                if (mappedModeles.length === 0) {
                    Alert.alert('Aucun modèle trouvé pour cette marque.');
                }
            } else {
                Alert.alert(json.message || json.error);
            }
        })
        .catch((error) => console.error(error));
};
 
    // Fonction pour ajouter un nouveau véhicule
    const handleAjoutVehicule = async () => {
        const immatError = immatValidator(immat);
        const motorisationError = motorisationValidator(motorisation);
        const couleurError = couleurValidator(couleur);
        const kilometrageError = kilometrageValidator(kilometrage);
        const placesError = placesValidator(places);
        const vitesseError = vitesseValidator(Boitevitesse);
        const tarifJourError = tarifJourValidator(tarifJour);
        const descriptionError = descriptionValidator(description);
    
        try {
            if (!selectedMarque || !selectedModele || !selectedTypeVehicule || immatError || !annee || motorisationError || couleurError || kilometrageError || placesError || vitesseError || tarifJourError || !selectedStatut || descriptionError || !niveauCarburant) {
                Alert.alert('Veuillez remplir tous les champs');
                return;
            }
            const formattedAnnee = `${annee.getFullYear()}-${('0' + (annee.getMonth() + 1)).slice(-2)}-${('0' + annee.getDate()).slice(-2)}`;
            const formData = new FormData();
            formData.append('idMarque', selectedMarque);
            formData.append('idModele', selectedModele);
            formData.append('idTypeVehicule', selectedTypeVehicule);
            formData.append('immat', immat);
            formData.append('annee', formattedAnnee);
            formData.append('motorisation', motorisation);
            formData.append('couleur', couleur);
            formData.append('kilometrage', kilometrage);
            formData.append('places', places);
            formData.append('Boitevitesse', Boitevitesse);
            formData.append('tarifJour', tarifJour);
            formData.append('idStatut', selectedStatut);
            formData.append('description', description);
            formData.append('niveauCarburant', niveauCarburant);
              
            const response = await fetch('https://sites.freeboxos.fr/Api/Vehicules/insertVehicule.php', {
                method: 'POST',
                body: formData,
            });
    
            const data = await response.json();
            if (data.success) {
                Alert.alert('Succès', 'Le véhicule a été ajouté avec succès.');
                setSelectedMarque('');
                setSelectedModele('');
                setSelectedTypeVehicule('');
                setImmat('');
                setAnnee(new Date());
                setMotorisation('');
                setCouleur('');
                setKilometrage('');
                setPlaces('');
                setBoitevitesse('');
                setTarifJour('');
                setDescription('');
                setSelectedStatut('');
                setNiveauCarburant('');
                navigation.navigate("Vehicules");
            } else {
                Alert.alert('Erreur', data.error || 'Une erreur s\'est produite lors de l\'ajout du véhicule.');
            }
        } catch (error) {
           
            Alert.alert('Erreur', 'Une erreur s\'est produite lors de l\'ajout du véhicule.');
        }
    };
    
 

    return (
        <ScrollView>
            <Header title="Ajout de véhicule" />
            <View style={styles.container}>
                <DropDown
                    data={marques}
                    onSelect={value => setSelectedMarque(value)}
                    placeholder="Sélectionnez une marque"
                  
                />
                <DropDown
                    data={modeles}
                    onSelect={value => setSelectedModele(value)}
                    placeholder="Sélectionnez un modèle"
                  
                />
                <DropDown
                    data={typesVehicule}
                    onSelect={value => setSelectedTypeVehicule(value)}
                    placeholder="Sélectionnez un type de véhicule"
                
                />
                <DropDown
                    data={statuts}
                    onSelect={value => setSelectedStatut(value)}
                    placeholder="Sélectionnez un statut"
              
                />
       
            {/* Date du véhicule */}
            <View style={styles.formGroup}>
                <Text style={styles.label}>date du véhicule</Text>
                <DatePicker value={annee} onChange={setAnnee} />
            </View>

                <View style={styles.formGroup}>
                    <Text style={styles.label}>Immatriculation:</Text>
                    <InputText value={immat} onChangeText={setImmat} placeholder="Entrer une plaque d'immatriculation valide" />
                </View>
              
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Motorisation:</Text>
                    <InputText value={motorisation} onChangeText={setMotorisation} placeholder="ex: Diesel/Essence"/>
                </View>
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Couleur:</Text>
                    <InputText value={couleur} onChangeText={setCouleur} placeholder="ex: noir/bleu" />
                </View>
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Kilométrage:</Text>
                    <InputText value={kilometrage} onChangeText={setKilometrage} placeholder="Km"/>
                </View>
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Nombre de places:</Text>
                    <InputText value={places} onChangeText={setPlaces} placeholder="Places dans le véhicule"/>
                </View>
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Vitesse:</Text>
                    <InputText value={Boitevitesse} onChangeText={setBoitevitesse}  placeholder="Vitesse"/>
                </View>
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Tarif par jour:</Text>
                    <InputText value={tarifJour} onChangeText={setTarifJour} placeholder="Tarif/jour de location"/>
                </View>
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Description:</Text>
                    <InputText value={description} onChangeText={setDescription} placeholder="Description" />
                </View>
        
                <ProgressBarSlider
      label="Niveau Essence:"
      value={niveauCarburant}
      onValueChange={setNiveauCarburant}
    />
                <Boutton onPress={handleAjoutVehicule} value="Ajouter" />   
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        paddingHorizontal: 20,
        paddingTop: 20,
    },
    formGroup: {
        marginBottom: 20,
    },
    label: {
        marginBottom: 5,
        fontSize: 16,
    },
});

export default AjoutVehicule;
