import React, { useEffect, useState } from 'react';
import {  StyleSheet, Alert, ScrollView, View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; // Importer useNavigation
import InputText from '../../Components/InputText';
import Header from '../../Components/Header';
import DropDown from '../../Components/DropDown';
import ProgressBarSlider from '../../Components/ProgressBarSlider';
import Footer from '../../Components/Footer';
import Text from '../../Components/Text';

const VehiculeDetails = ({ route }) => {
    const selectedItem = route?.params?.selectedItem || {}; 
    const navigation = useNavigation(); // Utiliser useNavigation pour obtenir l'objet de navigation
    const [marques, setMarques] = useState([]);
    const [modeles, setModeles] = useState([]);
    const [statuts, setStatuts] = useState([]); 
    const [typeVehicule, setTypeVehicule] = useState([]);
    const [editedMarque, setEditedMarque] = useState(selectedItem.idMarque);
    const [editedModele, setEditedModele] = useState(selectedItem.idModele);
    const [editedTypeVehicule, setEditedTypeVehicule] = useState(selectedItem.idTypeVehicule);
    const [editedImmat, setEditedImmat] = useState(selectedItem.Immat);
    const [editedKilometrage, setEditedKilometrage] = useState(selectedItem.kilometrage);
    const [editedAnnee, setEditedAnnee] = useState(selectedItem.annee);
    const [editedTarifJour, setEditedTarifJour] = useState(selectedItem.TarifJour);
    const [editedDescription, setEditedDescription] = useState(selectedItem.description);
    const [editedCouleur, setEditedCouleur] = useState(selectedItem.Couleur);
    const [editedCarburant, setEditedCarburant] = useState(selectedItem.niveauCarburant);
    const [editedBoiteVitesse, setEditedBoiteVitesse] = useState(selectedItem.BoiteVitesse);
    const [editedPlaces, setEditedPlaces] = useState(selectedItem.Places);
    const [editedStatut, setEditedStatut] = useState(selectedItem.idStatut);
    const [editedMotorisation, setEditedMotorisation] = useState(selectedItem.motorisation);
    const [idVehicule, setIdVehicule] = useState(selectedItem.idVehicule);
    


    useEffect(() => {
        fetchMarque();
        fetchModeles(selectedItem.idMarque); 
        fetchTypeVehicule();
        fetchStatuts();

    }, []);

    const fetchStatuts = () => {    
        fetch(`https://sites.freeboxos.fr/Api/Listes/getStatuts.php`)

            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    const mappedStatuts = json.statuts.map(statut => ({ label: statut.Statut, value: statut.idStatut }));
                    setStatuts(mappedStatuts);
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };


    // Fonction pour récupérer les marques
    const fetchMarque = () => {
        fetch(`https://sites.freeboxos.fr/Api/Listes/getMarques.php`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    const mappedMarques = json.marques.map(marque => ({ label: marque.nom, value: marque.idMarque }));
                    setMarques(mappedMarques);
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };

    // Fonction pour récupérer les modèles en fonction de l'identifiant de la marque sélectionnée
    const fetchModeles = (idMarque) => {
        fetch(`https://sites.freeboxos.fr/Api/Listes/getModeles.php?idMarque=${idMarque}`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    const mappedModeles = json.modeles.map(modele => ({ label: modele.nom, value: modele.idModele }));
                    setModeles(mappedModeles);
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };

    // Fonction pour récupérer les types de véhicules
    const fetchTypeVehicule = () => {
        fetch(`https://sites.freeboxos.fr/Api/Listes/getTypesVehicules.php`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    const mappedTypesVehicules = json.typesVehicules.map(type => ({ label: type.nomType, value: type.idTypeVehicule }));
                    setTypeVehicule(mappedTypesVehicules);
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error));
    };

    // Fonction pour modifier l'élément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idMarque', editedMarque);
            formData.append('idModele', editedModele);
            formData.append('idTypeVehicule', editedTypeVehicule);
            formData.append('idStatut', editedStatut);
            formData.append('Immat', editedImmat);
            formData.append('kilometrage', editedKilometrage);
            formData.append('annee', editedAnnee);
            formData.append('TarifJour', editedTarifJour);
            formData.append('description', editedDescription);
            formData.append('Couleur', editedCouleur);
            formData.append('niveauCarburant', editedCarburant);
            formData.append('BoiteVitesse', editedBoiteVitesse);
            formData.append('Places', editedPlaces);
            formData.append('motorisation', editedMotorisation);
            formData.append('idVehicule', idVehicule);

            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/updateVehicule.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
               
                Alert.alert('Succès', data.message);
                navigation.navigate("Vehicules");
                setEditedAnnee('');
                setEditedImmat('');
                setEditedKilometrage('');
                setEditedTarifJour('');
                setEditedDescription('');
                setEditedCouleur('');
                setEditedCarburant('');
                setEditedBoiteVitesse('');
                setEditedPlaces('');
                setEditedMotorisation('');
              

            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer l'élément
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idVehicule', selectedItem.idVehicule);

            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/supprVehicule.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                navigation.navigate("Vehicules");
                Alert.alert('Succès', data.message);
            } else {
                const errorData = await response.json();
                if (errorData.error.includes('Impossible de supprimer la marque')) {
                    Alert.alert('Erreur', errorData.error);
                } else {
                    Alert.alert('Erreur lors de la suppression de l\'élément:', errorData.error);
                }
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };
   
    return (
        <ScrollView>
            <Header title="Détails du véhicule" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du véhicule: {selectedItem.idVehicule}</Text>

            <DropDown
                data={marques}
                onSelect={(value) => {
                    setEditedMarque(value);
                    fetchModeles(value); 
                }}
                placeholder="Sélectionnez une marque"
                selectedValue={selectedItem.idMarque}
             

            />
            <DropDown
                data={modeles}
                onSelect={(value) => setEditedModele(value)}
                placeholder="Sélectionnez un modèle"
                selectedValue={selectedItem.idModele}
                
            />
            <DropDown
                data={typeVehicule}
                onSelect={(value) => setEditedTypeVehicule(value)}
                placeholder="Sélectionnez un type de véhicule"
                selectedValue={selectedItem.idTypeVehicule}
               
            />
            <DropDown
                data={statuts}
                onSelect={(value) => setEditedStatut(value)}
                placeholder="Sélectionnez un statut"
                selectedValue={selectedItem.idStatut}
             
            />
         
      <ProgressBarSlider
  label="Niveau Carburant:"
  value={parseFloat(editedCarburant)}
  onValueChange={setEditedCarburant}
/>
            <Text>Immatriculation :</Text>
            <InputText
                label="Immatriculation"
                value={editedImmat}
                onChangeText={setEditedImmat}
            />
            <Text>Kilométrage :</Text>
            <InputText  
                label="Kilométrage"
                value={editedKilometrage.toString()}
                onChangeText={setEditedKilometrage}
            />
          <Text>Année :</Text>
            <InputText
                label="Année"
                value={editedAnnee}
                onChangeText={setEditedAnnee}
            />
            <Text>Tarif journalier :</Text>
            <InputText
                label="Tarif journalier"
                value={editedTarifJour.toString()}
                onChangeText={setEditedTarifJour}
            />
        <Text>Description :</Text>
            <InputText
                label="Description"
                value={editedDescription}
                onChangeText={setEditedDescription}
            />
            <Text>Couleur :</Text>
            <InputText
                label="Couleur"
                value={editedCouleur}
                onChangeText={setEditedCouleur}
            />
          <Text>Boite de Vistesse :</Text>
            <InputText
                label="Boite de vitesse"
                value={editedBoiteVitesse.toString()}
                onChangeText={setEditedBoiteVitesse}
            />
            <Text>Nombre de places :</Text>
            <InputText
    label="Nombre de places"
    value={editedPlaces.toString()} 
    onChangeText={setEditedPlaces}
    keyboardType="numeric" 
/>
                <Text>Motorisation :</Text>
            <InputText
                label="Motorisation"
                value={editedMotorisation}
                onChangeText={setEditedMotorisation}
            />
          
          <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
});

export default VehiculeDetails;
